(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    913552,      20831]
NotebookOptionsPosition[    906025,      20638]
NotebookOutlinePosition[    906379,      20654]
CellTagsIndexPosition[    906336,      20651]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Jeffrey-Kirwan residue formula in CoulombHiggs.m", "Title",
 CellChangeTimes->{{3.771120910464164*^9, 
  3.77112092604918*^9}},ExpressionUUID->"11816b1a-eba9-471a-ba6f-\
f0b9715d1f64"],

Cell["\<\
As in [arXiv:1907.01354]\[NonBreakingSpace]we consider the Kronecker quiver \
of rank (2,3) with 3 arrows;
Updated to CoulombHiggs6.0 on Dec 2020\
\>", "Text",
 CellChangeTimes->{{3.771120971111164*^9, 3.771121018657048*^9}, {
  3.8182264571907063`*^9, 
  3.818226467306418*^9}},ExpressionUUID->"be38471f-afdf-411e-8392-\
5ab921b77c5b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "CoulombHiggs`"}]}], "Input",ExpressionUUID->"c234fc8c-16e3-\
49ef-a64b-33e01f8d038e"],

Cell[BoxData["\<\"CoulombHiggs 6.0 - A package for evaluating quiver \
invariants\"\>"], "Print",
 CellChangeTimes->{3.771121031242648*^9, 3.771121114697061*^9, 
  3.818226468866413*^9},ExpressionUUID->"43f9b8a8-c16b-4184-b65a-\
738de7763dd6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "0"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RMat", "=", 
   RowBox[{"0", "Mat"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cvec", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}], "/", "Nvec"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"QuiverPlot", "[", "Mat", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$QuiverNoVM", "=", "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$QuiverTrig", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"$QuiverVerbose", "=", "False"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"JKInitialize", 
  StyleBox["[", "MSG"], 
  StyleBox[
   RowBox[{"Mat", ",", "RMat", ",", "Cvec", ",", "Nvec"}], "MSG"], 
  StyleBox["]", "MSG"]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"JKChargeMatrix", "//", "MatrixForm"}], ",", " ", "JKEta"}], 
  "}"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.771121105062152*^9, 
  3.771121166912756*^9}},ExpressionUUID->"198a1105-fb0c-4938-a09a-\
257aa678c02a"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7BnQQPKxIyaL1t2wLTitpuMWu8veob5N1y12
ln3P8zpbpV0H7Cc8XN38rmyBvZ7c5Js5PkfsG9LvMG62X2w/bcY515Qnx+0N
alikBTuW2gt+MRV70XDafsIRpVmB/svtN+UeKLymcN4+4fuXI0+nrLCPLJ5t
1pZ40X6BxPaO9IiV9rr5JsbGxpftGS4pz5o5c6V9PEt6WlraM/uEa1dmgvgq
9Zuf2Pg/t294HANW/0N4YvIp8xf2AT39YPPWLSr+dVT+pf0ErU0zQfbNSu59
94ztlf2BvR1SIPdwqM05+eTNK/sNk0LB7g0VXFhQfvG1PQOHFNg/HierrcK3
vLF3eOOjA/Lvn62KEP8zHdIC8vef2lUN9v+HSSFNQPX7f6X3g/2/QHYCA9C8
/VsKT4H9v8HjsCTQvv2ppYZg/xdsfTMD6J79dht2g/3vIH7qMNC9+48yzgT7
PyFvejvQP/sDvxuC/e+QyA/y7/78E6lg/z+IiQPzo9w2Qfy/+CNY/awn/WD/
GzTpg/y/n6m5COz/Av9YkP/3P4jsAfufgd0e5P/9VRazwf4P+CQG8v9+ZbcF
YP8n5DwD+2eGGsT/B6b81gb5FwAEsgUQ
    "], {{
      {RGBColor[0.5, 0., 0.], Arrowheads[{{0.041582132564841494`, 0.7}}], 
       ArrowBox[{2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 
        1}], ArrowBox[{2, 1}], 
       ArrowBox[{2, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
        33, 34, 1}]}}, {InsetBox[
       FrameBox["1",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox["2",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{1., 0.}, {0., 8.979318433952318*^-11}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{{3.771121111381513*^9, 3.771121167297017*^9}, 
   3.818226469963002*^9},ExpressionUUID->"2d531531-51e9-465d-8193-\
8d501ef65f75"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "1"}], "0", "1", "0", "0", "0", "3"},
       {"0", 
        RowBox[{"-", "1"}], "1", "0", "0", "0", "3"},
       {
        RowBox[{"-", "1"}], "0", "0", "1", "0", "0", "3"},
       {"0", 
        RowBox[{"-", "1"}], "0", "1", "0", "0", "3"},
       {
        RowBox[{"-", "1"}], "0", "0", "0", "1", "0", "3"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0", "1", "0", "3"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["624999981", "1250000000"]}], ",", 
     RowBox[{"-", 
      FractionBox["1249999891", "2500000000"]}], ",", 
     FractionBox["2500001581", "7500000000"], ",", 
     FractionBox["2500002553", "7500000000"], ",", 
     FractionBox["2500002613", "7500000000"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.771121111381513*^9, 3.771121167297017*^9}, 
   3.818226469975031*^9},ExpressionUUID->"b3cbb73a-c53d-430d-b60a-\
72eeb11dd2b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["First compute the index using Reineke\[CloseCurlyQuote]s formula", \
"Subsection",
 CellChangeTimes->{{3.771121229670414*^9, 
  3.7711212448376207`*^9}},ExpressionUUID->"82cfc3f6-9173-4ba4-9b99-\
58e53e942ce7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Higgs", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"HiggsBranchFormula", "[", 
     RowBox[{"Mat", ",", "Cvec", ",", "Nvec"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{"Higgs", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "1", ",", "0"}], "}"}]}], "]"}], ",", "Higgs"}], 
  "}"}]}], "Input",
 CellChangeTimes->{
  3.771121267892045*^9, {3.7711213760878563`*^9, 
   3.771121380698189*^9}},ExpressionUUID->"9a25b8f6-81a6-4d81-838c-\
aa5033a541e5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{"13", "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        RowBox[{"y", "-", "1"}], "]"}], "1"],
      SeriesData[CoulombHiggs`y, 1, {}, 0, 1, 1],
      Editable->False]}],
    SeriesData[CoulombHiggs`y, 1, {13}, 0, 1, 1],
    Editable->False], ",", 
   RowBox[{"3", "+", 
    FractionBox["1", 
     SuperscriptBox["y", "6"]], "+", 
    FractionBox["1", 
     SuperscriptBox["y", "4"]], "+", 
    FractionBox["3", 
     SuperscriptBox["y", "2"]], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "+", 
    SuperscriptBox["y", "6"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.771121257983374*^9, 3.771121268408593*^9}, 
   3.7711213809921627`*^9, 
   3.818226472396331*^9},ExpressionUUID->"22d60a40-af88-4ed4-820d-\
00bd77f2a42b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Next using the residue formula ", "Subsection",
 CellChangeTimes->{{3.771121229670414*^9, 3.7711212448376207`*^9}, {
  3.771121293969455*^9, 
  3.7711213035862303`*^9}},ExpressionUUID->"6c65a787-8d01-4395-83cf-\
a69f0b606e96"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JKIndex", "[", 
  RowBox[{"JKChargeMatrix", ",", "Nvec", ",", "JKEta"}], "]"}]], "Input",Expre\
ssionUUID->"c181a47b-f323-4911-94cd-9fd2335da693"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"4", "\[InvisibleSpace]", "\<\" stable flags in total\"\>"}],
  SequenceForm[4, " stable flags in total"],
  Editable->False]], "Print",
 CellChangeTimes->{3.771121313567232*^9, 
  3.818226480952874*^9},ExpressionUUID->"e830ac81-b469-4132-8209-\
6279c73cf832"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"From computing the Euler number, \"\>", "\[InvisibleSpace]", 
   "4", "\[InvisibleSpace]", "\<\" stable flags appear to contribute\"\>"}],
  SequenceForm[
  "From computing the Euler number, ", 4, 
   " stable flags appear to contribute"],
  Editable->False]], "Print",
 CellChangeTimes->{3.771121313567232*^9, 
  3.818226481984888*^9},ExpressionUUID->"07041b07-4a1a-41f6-ace6-\
54f78444d4aa"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"7", "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"55", " ", 
       SuperscriptBox["y", "4"]}], "+", 
      RowBox[{"69", " ", 
       SuperscriptBox["y", "6"]}], "+", 
      RowBox[{"55", " ", 
       SuperscriptBox["y", "8"]}], "+", 
      RowBox[{"27", " ", 
       SuperscriptBox["y", "10"]}], "+", 
      RowBox[{"7", " ", 
       SuperscriptBox["y", "12"]}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["y", "6"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "9"}], "-", 
      RowBox[{"29", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"61", " ", 
       SuperscriptBox["y", "4"]}], "-", 
      RowBox[{"75", " ", 
       SuperscriptBox["y", "6"]}], "-", 
      RowBox[{"61", " ", 
       SuperscriptBox["y", "8"]}], "-", 
      RowBox[{"29", " ", 
       SuperscriptBox["y", "10"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["y", "12"]}]}], 
     RowBox[{"6", " ", 
      SuperscriptBox["y", "6"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "9"}], "-", 
      RowBox[{"29", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"61", " ", 
       SuperscriptBox["y", "4"]}], "-", 
      RowBox[{"75", " ", 
       SuperscriptBox["y", "6"]}], "-", 
      RowBox[{"61", " ", 
       SuperscriptBox["y", "8"]}], "-", 
      RowBox[{"29", " ", 
       SuperscriptBox["y", "10"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["y", "12"]}]}], 
     RowBox[{"6", " ", 
      SuperscriptBox["y", "6"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "9"}], "-", 
      RowBox[{"29", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"61", " ", 
       SuperscriptBox["y", "4"]}], "-", 
      RowBox[{"75", " ", 
       SuperscriptBox["y", "6"]}], "-", 
      RowBox[{"61", " ", 
       SuperscriptBox["y", "8"]}], "-", 
      RowBox[{"29", " ", 
       SuperscriptBox["y", "10"]}], "-", 
      RowBox[{"9", " ", 
       SuperscriptBox["y", "12"]}]}], 
     RowBox[{"6", " ", 
      SuperscriptBox["y", "6"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.771121319867653*^9, 
  3.818226487704198*^9},ExpressionUUID->"632349de-f3ac-4916-b3a3-\
5193fceeaa21"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plus", "@@", "JKEuler"}], ",", 
   RowBox[{"Expand", "[", 
    RowBox[{"Plus", "@@", "JKChiGenus"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.771121331693129*^9, 
  3.771121394145934*^9}},ExpressionUUID->"25465b00-f882-4280-9fee-\
8bdda1ad1c7d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"13", ",", 
   RowBox[{"3", "+", 
    FractionBox["1", 
     SuperscriptBox["y", "6"]], "+", 
    FractionBox["1", 
     SuperscriptBox["y", "4"]], "+", 
    FractionBox["3", 
     SuperscriptBox["y", "2"]], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "+", 
    SuperscriptBox["y", "6"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7711213386801443`*^9, {3.771121369392725*^9, 3.771121394493868*^9}, 
   3.818226489786621*^9},ExpressionUUID->"77dd78d0-e21e-4e49-ad5a-\
dc68eda784ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"JKListuDisplay", "=", 
   RowBox[{"{", 
    RowBox[{"u1", ",", "u2", ",", "v1", ",", "v2", ",", "v3"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DisplayFlagList", "[", "JKRelevantStableFlags", "]"}]}], "Input",
 CellChangeTimes->{{3.771121446074194*^9, 
  3.77112144666297*^9}},ExpressionUUID->"5d701bf0-9b75-4184-bcde-\
c231ccc878a2"],

Cell[CellGroupData[{

Cell[BoxData["\<\"- List of (intersection point, stable flag, sign)\"\>"], \
"Print",
 CellChangeTimes->{3.7711214073281*^9, 3.771121446947009*^9, 
  3.818226491179521*^9},ExpressionUUID->"8bbe80e8-6e72-47ed-a270-\
fe3795078da1"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v3"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}]}], "}"}], 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.7711214073281*^9, 3.771121446947009*^9, 
  3.818226491192305*^9},ExpressionUUID->"749584e1-72ad-4cab-bc70-\
285bb7e28b00"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"JKVertexLabels", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "u1"}], ",", 
     RowBox[{"2", "\[Rule]", "v1"}], ",", 
     RowBox[{"3", "\[Rule]", "v1"}], ",", 
     RowBox[{"4", "\[Rule]", "v2"}], ",", 
     RowBox[{"5", "\[Rule]", "v3"}]}], "}"}]}], ";", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"DisplayFlagTree", "[", 
     RowBox[{"JKRelevantStableFlags", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "JKRelevantStableFlags", "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.771121487561235*^9, 
  3.7711214953055696`*^9}},ExpressionUUID->"3c4fe801-62ed-45f5-a79b-\
87bbe13a63d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 3, 2}, {{{1, 2}, {1, 3}, {1, 4}, {5, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> 0, DirectedEdge[1, 3] -> 0, 
           DirectedEdge[1, 5] -> 0, DirectedEdge[2, 5] -> 0}, EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}, {0, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {3, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> 0, DirectedEdge[1, 3] -> 0, 
           DirectedEdge[1, 5] -> 0, DirectedEdge[2, 5] -> 0}, EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {1, 4}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> 0, DirectedEdge[2, 4] -> 0, 
           DirectedEdge[1, 3] -> 0, DirectedEdge[1, 5] -> 0}, EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 2, 3}, {{{1, 2}, {1, 3}, {4, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> 0, DirectedEdge[1, 3] -> 0, 
           DirectedEdge[2, 3] -> 0, DirectedEdge[1, 5] -> 0}, EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox["0",
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None]}], "}"}]], "Output",
 CellChangeTimes->{3.771121496325314*^9, 
  3.818226494785041*^9},ExpressionUUID->"4272648e-6cea-4e57-afb3-\
ea630f6d86db"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Same but applying the Cauchy-Bose formula on the first node", \
"Subsection",
 CellChangeTimes->{{3.771121229670414*^9, 3.7711212448376207`*^9}, {
  3.771121293969455*^9, 3.7711213035862303`*^9}, {3.7711215193173723`*^9, 
  3.771121548218285*^9}},ExpressionUUID->"0d99f949-d62c-4310-99e1-\
d61aa1b8b7c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JKIndexSplit", "[", 
  RowBox[{"JKChargeMatrix", ",", "Nvec", ",", "JKEta", ",", 
   RowBox[{"{", "1", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.771121581048691*^9, 
  3.7711215846810303`*^9}},ExpressionUUID->"ef7c617c-c872-4284-83aa-\
6584d150df49"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2", "\[InvisibleSpace]", "\<\" partitions with coefficient in table below:\
\"\>"}],
  SequenceForm[2, " partitions with coefficient in table below:"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.8182264996748*^9},ExpressionUUID->"cac9ba8b-7b4d-475e-ab84-3e643a281a17"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "2", "}"}], ",", 
        RowBox[{"{", "}"}]}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", "}"}]}], "}"}], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.818226499682922*^9},ExpressionUUID->"cdeb9b03-27e5-408a-a104-\
1c30aab32b28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}], "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\" intersections, \"\>", 
   "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" stable flags in total\"\>"}],
  SequenceForm[
  "Partition", {{2}, {}}, ": ", 1, " intersections, ", 4, 
   " stable flags in total"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.818226499774663*^9},ExpressionUUID->"49288de7-835d-4f28-9314-\
f0a9b042a786"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}], "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\" intersections, \"\>", 
   "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" stable flags in total\"\>"}],
  SequenceForm[
  "Partition", {{1, 1}, {}}, ": ", 1, " intersections, ", 4, 
   " stable flags in total"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.8182264998981113`*^9},ExpressionUUID->"888b8c98-442d-45d7-a088-\
4e1554613868"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" distinct intersections in total\"\>"}],
  SequenceForm[1, " distinct intersections in total"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.818226499909356*^9},ExpressionUUID->"980b33a6-d4d8-4b8e-9875-\
3f08e0e3f6e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}],
  SequenceForm["Partition ", {{2}, {}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.818226499918393*^9},ExpressionUUID->"1ca05ee5-d75a-4fc3-be89-\
f6faee9a07a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}],
  SequenceForm["Partition ", {{1, 1}, {}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.8182265008779984`*^9},ExpressionUUID->"b4335e08-09c1-4cb4-99dd-\
e176083282ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"From computing the Euler number, \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" stable flags appear to contribute: \"\>"}],
  SequenceForm[
  "From computing the Euler number, ", {4, 4}, 
   " stable flags appear to contribute: "],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.8182265017355137`*^9},ExpressionUUID->"e87f2c98-c7a6-43aa-8798-\
8fa4ba4e40e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "2", "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}],
  SequenceForm["Partition ", {{2}, {}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.8182265017469788`*^9},ExpressionUUID->"b0abfa80-7469-4308-a3e6-\
cdf58e99b147"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}],
  SequenceForm["Partition ", {{1, 1}, {}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7711215851421337`*^9, 
  3.818226505995566*^9},ExpressionUUID->"5c2789fa-1feb-4ba3-acb5-\
8b88db06a185"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{"28", " ", 
         SuperscriptBox["y", "4"]}], "+", 
        RowBox[{"56", " ", 
         SuperscriptBox["y", "6"]}], "+", 
        RowBox[{"70", " ", 
         SuperscriptBox["y", "8"]}], "+", 
        RowBox[{"56", " ", 
         SuperscriptBox["y", "10"]}], "+", 
        RowBox[{"28", " ", 
         SuperscriptBox["y", "12"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["y", "14"]}], "+", 
        SuperscriptBox["y", "16"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["y", "8"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "8"}], "-", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{"68", " ", 
         SuperscriptBox["y", "6"]}], "-", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "8"]}], "-", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", "10"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["y", "12"]}]}], 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "6"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "8"}], "-", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{"68", " ", 
         SuperscriptBox["y", "6"]}], "-", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "8"]}], "-", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", "10"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["y", "12"]}]}], 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "6"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "8"}], "-", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{"68", " ", 
         SuperscriptBox["y", "6"]}], "-", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "8"]}], "-", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", "10"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["y", "12"]}]}], 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "6"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        SuperscriptBox["y", "2"], "-", 
        SuperscriptBox["y", "4"], "-", 
        SuperscriptBox["y", "6"], "-", 
        SuperscriptBox["y", "8"], "-", 
        SuperscriptBox["y", "10"], "-", 
        SuperscriptBox["y", "12"], "-", 
        SuperscriptBox["y", "14"], "-", 
        SuperscriptBox["y", "16"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["y", "8"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["y", "6"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", "8"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "10"]}], "-", 
        SuperscriptBox["y", "12"]}], 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "6"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["y", "6"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", "8"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "10"]}], "-", 
        SuperscriptBox["y", "12"]}], 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "6"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["y", "6"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", "8"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "10"]}], "-", 
        SuperscriptBox["y", "12"]}], 
       RowBox[{"6", " ", 
        SuperscriptBox["y", "6"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.771121595853697*^9, 
  3.81822650985721*^9},ExpressionUUID->"91062736-2093-4f6f-9ddc-266465cbc98d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plus", "@@", "JKEuler"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Plus", "@@", "JKChiGenus"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.771121672401396*^9, 
  3.771121717288577*^9}},ExpressionUUID->"2d9a75e7-5efd-4a46-8010-\
d77aba6c52e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["247", "2"]}], ",", 
     FractionBox["91", "2"], ",", 
     FractionBox["91", "2"], ",", 
     FractionBox["91", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"7", "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "4"]}], "+", 
        RowBox[{"69", " ", 
         SuperscriptBox["y", "6"]}], "+", 
        RowBox[{"55", " ", 
         SuperscriptBox["y", "8"]}], "+", 
        RowBox[{"27", " ", 
         SuperscriptBox["y", "10"]}], "+", 
        RowBox[{"7", " ", 
         SuperscriptBox["y", "12"]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["y", "6"]}]]}], ",", 
     FractionBox[
      RowBox[{"9", "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"61", " ", 
        SuperscriptBox["y", "4"]}], "+", 
       RowBox[{"75", " ", 
        SuperscriptBox["y", "6"]}], "+", 
       RowBox[{"61", " ", 
        SuperscriptBox["y", "8"]}], "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", "10"]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["y", "12"]}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "6"]}]], ",", 
     FractionBox[
      RowBox[{"9", "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"61", " ", 
        SuperscriptBox["y", "4"]}], "+", 
       RowBox[{"75", " ", 
        SuperscriptBox["y", "6"]}], "+", 
       RowBox[{"61", " ", 
        SuperscriptBox["y", "8"]}], "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", "10"]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["y", "12"]}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "6"]}]], ",", 
     FractionBox[
      RowBox[{"9", "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"61", " ", 
        SuperscriptBox["y", "4"]}], "+", 
       RowBox[{"75", " ", 
        SuperscriptBox["y", "6"]}], "+", 
       RowBox[{"61", " ", 
        SuperscriptBox["y", "8"]}], "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", "10"]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["y", "12"]}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["y", "6"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.771121675280821*^9, 3.771121717711722*^9}, 
   3.818226511617614*^9},ExpressionUUID->"11ade4f2-9bce-4bd2-a487-\
aaf93f89b009"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", "JKChiGenus", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "1", ",", "0"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7711216527413054`*^9, 
  3.7711216528194532`*^9}},ExpressionUUID->"e853196a-05f6-48e9-be79-\
9854b4f40295"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "128"}], ",", "41", ",", "41", ",", "41"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", 
     FractionBox["9", "2"], ",", 
     FractionBox["9", "2"], ",", 
     FractionBox["9", "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.77112164955763*^9, 3.771121653176393*^9}, 
   3.8182265127863693`*^9},ExpressionUUID->"2bab2c8b-20de-47ff-8e93-\
63f555b6059a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Partition \>\"", ",", 
      RowBox[{"PermutationToPartition", "[", 
       RowBox[{"JKListAllPerms", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1", ",", "1"}], "]"}], "]"}], "]"}]}], "]"}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"DisplayFlagList", "[", 
     RowBox[{"JKRelevantStableFlags", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.771121751313898*^9, 3.771121788480957*^9}, {
  3.771121836640293*^9, 
  3.771121912334553*^9}},ExpressionUUID->"8c896799-98a1-42de-ab45-\
e50beaa62128"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "2", "}"}]}],
  SequenceForm["Partition ", {2}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.771121862050715*^9, 3.771121912658485*^9}, 
   3.818226514749385*^9},ExpressionUUID->"9c6f461e-5ec8-4dbf-9c9c-\
6bbdaef15c99"],

Cell[BoxData["\<\"- List of (intersection point, stable flag, sign)\"\>"], \
"Print",
 CellChangeTimes->{{3.771121862050715*^9, 3.771121912658485*^9}, 
   3.818226514756871*^9},ExpressionUUID->"0ac9a893-aa32-4245-b174-\
782788d415d9"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v3"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}]}], "}"}], 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.771121862050715*^9, 3.771121912658485*^9}, 
   3.818226514768833*^9},ExpressionUUID->"1d8a8ebb-52aa-4225-bff2-\
51d5fef6f22e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partition \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}],
  SequenceForm["Partition ", {1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.771121862050715*^9, 3.771121912658485*^9}, 
   3.818226514780614*^9},ExpressionUUID->"e457919f-4518-4bc2-9f47-\
ea6a8dc2b9e9"],

Cell[BoxData["\<\"- List of (intersection point, stable flag, sign)\"\>"], \
"Print",
 CellChangeTimes->{{3.771121862050715*^9, 3.771121912658485*^9}, 
   3.8182265147920094`*^9},ExpressionUUID->"9eecf1b4-7bd0-4f2b-a566-\
872adb37f1d4"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v3"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}]}], "}"}], 
      RowBox[{"-", "1"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v3"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v2"}], ",", 
        RowBox[{
         RowBox[{"-", "u2"}], "+", "v1"}], ",", 
        RowBox[{
         RowBox[{"-", "u1"}], "+", "v1"}]}], "}"}], 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.771121862050715*^9, 3.771121912658485*^9}, 
   3.8182265148038692`*^9},ExpressionUUID->"2f6583a3-8ace-4442-a336-\
61ff14ca739b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the equivariant chi-genus", "Subsection",
 CellChangeTimes->{{3.771121229670414*^9, 3.7711212448376207`*^9}, {
  3.771121293969455*^9, 3.7711213035862303`*^9}, {3.7711215193173723`*^9, 
  3.771121548218285*^9}, {3.7711219584593487`*^9, 
  3.77112196863265*^9}},ExpressionUUID->"5dedb1a6-500c-4f24-af05-\
b1dde4a3c80b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RMat", "=", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"FlavoredRMatrix", "[", "Mat", "]"}]}], "/.", 
    RowBox[{
     RowBox[{"th", "[", "i_", "]"}], "\[RuleDelayed]", 
     SubscriptBox["\[Theta]", "i"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$QuiverNoVM", "=", "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$QuiverVerbose", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"JKInitialize", "[", 
   RowBox[{"Mat", ",", "RMat", ",", "Cvec", ",", "Nvec"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"JKChargeMatrix", "//", "MatrixForm"}], ",", " ", "JKEta"}], 
  "}"}]}], "Input",
 CellChangeTimes->{{3.771122022513772*^9, 
  3.771122036314962*^9}},ExpressionUUID->"9f22d712-3db5-4fcf-bb2c-\
235528a0e199"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "1"}], "0", "1", "0", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "1"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "1", "0", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "2"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "1", "0", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "3"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "1", "0", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "1"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "1", "0", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "2"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "1", "0", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "3"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "0", "1", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "1"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "0", "1", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "2"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "0", "1", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "3"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "0", "1", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "1"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "0", "1", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "2"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "0", "1", "0", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "3"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "0", "0", "1", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "1"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "0", "0", "1", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "2"]}], "1"},
       {
        RowBox[{"-", "1"}], "0", "0", "0", "1", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "3"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0", "1", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "1"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0", "1", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "2"]}], "1"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0", "1", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Theta]", "3"]}], "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["312499997", "625000000"]}], ",", 
     RowBox[{"-", 
      FractionBox["312499877", "625000000"]}], ",", 
     FractionBox["78125051", "234375000"], ",", 
     FractionBox["62500051", "187500000"], ",", 
     FractionBox["312500303", "937500000"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7711220232709303`*^9, 
  3.771122036766262*^9}},ExpressionUUID->"822f36cd-7c6d-4bfc-ab41-\
e416069d5c88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"JKIndex", "[", 
   RowBox[{"JKChargeMatrix", ",", "Nvec", ",", "JKEta"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.771122880968193*^9},ExpressionUUID->"a5112295-9c5b-426c-bbd2-\
bb5b83a06270"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"348", "\[InvisibleSpace]", "\<\" stable flags in total\"\>"}],
  SequenceForm[348, " stable flags in total"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.771122048289627*^9},ExpressionUUID->"26e45682-1203-4174-9541-\
067ba009610b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"From computing the Euler number, \"\>", "\[InvisibleSpace]", 
   "168", "\[InvisibleSpace]", "\<\" stable flags appear to contribute\"\>"}],
  
  SequenceForm[
  "From computing the Euler number, ", 168, 
   " stable flags appear to contribute"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.771122104183436*^9},ExpressionUUID->"77f3e653-61b7-49c5-81c4-\
8595218ef8b4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plus", "@@", "JKEuler"}], ",", 
    RowBox[{"Plus", "@@", "JKChiGenus"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.771122425147707*^9, 
  3.771122473878121*^9}},ExpressionUUID->"0b1f0607-3c42-4777-bd5e-\
c74403c58290"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"13", ",", 
   RowBox[{"3", "+", 
    FractionBox["1", 
     SuperscriptBox["y", "6"]], "+", 
    FractionBox["1", 
     SuperscriptBox["y", "4"]], "+", 
    FractionBox["3", 
     SuperscriptBox["y", "2"]], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    SuperscriptBox["y", "4"], "+", 
    SuperscriptBox["y", "6"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7711224280063562`*^9, 3.77112244490993*^9}, 
   3.771122476530527*^9},ExpressionUUID->"05f3e759-35bc-4419-af37-\
3433b23b3f2b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Distinct", " ", "contributions", " ", "to", " ", "equivariant", " ", 
    "Euler", " ", "number"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Tally", "[", 
   RowBox[{"Simplify", "[", "JKEuler", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.771122550033228*^9, 3.7711225539329777`*^9}, {
   3.771122630147147*^9, 3.7711226319561863`*^9}, 3.771122688120434*^9, {
   3.771122749746945*^9, 3.771122753555458*^9}, {3.771122909018962*^9, 
   3.771122926101839*^9}},ExpressionUUID->"1c5d27e1-b872-41f1-a558-\
a86146286728"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "180"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]]}], ",", "6"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]], ",", "18"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubscriptBox["\[Theta]", "2"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["\[Theta]", "1"]}], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]]}], ",", "12"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Theta]", "1"], "+", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Theta]", "2"], "+", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}], 
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "2"]}], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["\[Theta]", "1"]}], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]]}], ",", "12"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Theta]", "1"], "+", 
           SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubscriptBox["\[Theta]", "2"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}], 
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["\[Theta]", "1"]}], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]]}], ",", "12"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "1"]}], "-", 
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Theta]", "2"], "+", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}], 
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "1"], "-", 
           SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Theta]", "2"], "-", 
           SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["\[Theta]", "1"]}], "+", 
          SubscriptBox["\[Theta]", "2"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}]}]]}], ",", "12"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "1"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "2"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["\[Theta]", "1"], "+", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "+", 
         SubscriptBox["\[Theta]", "2"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "3"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Theta]", "1"], "-", 
          SubscriptBox["\[Theta]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Theta]", "1"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Theta]", "2"]}], "+", 
         SubscriptBox["\[Theta]", "3"]}], ")"}]}]], ",", "12"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.771122554407774*^9, 3.771122632280072*^9, 
  3.7711226887510443`*^9, 3.7711227542648783`*^9, 
  3.771122926681912*^9},ExpressionUUID->"86eb9a2d-9a21-4f89-830d-\
f6dfb347cddb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Distinct", " ", "contributions", " ", "to", " ", "equivariant", " ", 
    "Chi", " ", "genus", " ", "number"}], " ", "*)"}], 
  RowBox[{"Tally", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{"JKChiGenus", "/.", 
      RowBox[{
       SubscriptBox["\[Theta]", "i_"], "\[RuleDelayed]", 
       RowBox[{
        RowBox[{
         RowBox[{"Log", "[", 
          SubscriptBox["\[Nu]", "i"], "]"}], "/", "2"}], "/", 
        RowBox[{"Log", "[", "y", "]"}]}]}]}], ")"}], "]"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.771122651542571*^9, 3.771122742676403*^9}, {
  3.7711229388961554`*^9, 
  3.771122943205505*^9}},ExpressionUUID->"df98b11e-6417-4a17-a4b2-\
39be65b839c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "1"]}], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "2"]}], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], 
       RowBox[{"12", " ", 
        SuperscriptBox["y", "6"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Nu]", "1"], "-", 
           SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Nu]", "1"], "-", 
           SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Nu]", "2"], "-", 
           SubscriptBox["\[Nu]", "3"]}], ")"}], "2"]}]]}], ",", "6"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"]}]], ",", "18"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], " ", 
           SubscriptBox["\[Nu]", "1"]}], "+", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], " ", 
           SubscriptBox["\[Nu]", "2"]}], "+", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["y", "2"]}], " ", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "1", "2"]}], "-", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "2", "2"], "-", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Nu]", "1", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}]], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "1", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "+", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "1", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "2", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "+", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"]}]], ",", "12"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "1", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "2", "2"], "-", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Nu]", "1", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}]}]], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "1", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "+", 
         SubscriptBox["\[Nu]", "3"]}], ")"}]}]], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], " ", 
           SubscriptBox["\[Nu]", "2"]}], "+", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "1", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "1", "2"], "-", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], " ", 
           SubscriptBox["\[Nu]", "1"]}], "+", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "1", "2"]}], "-", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "3", "2"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "1", "2"], "-", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "1", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "3", "2"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "+", 
         SubscriptBox["\[Nu]", "3"]}], ")"}]}]], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], " ", 
           SubscriptBox["\[Nu]", "1"]}], "+", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], " ", 
           SubscriptBox["\[Nu]", "1"]}], "+", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}]], ",", "12"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "+", 
         SubscriptBox["\[Nu]", "3"]}], ")"}]}]], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "1"]}], "-", 
         SubscriptBox["\[Nu]", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "1"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Nu]", "2", "2"], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "3", "2"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "2"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Nu]", "2"], "+", 
         SubscriptBox["\[Nu]", "3"]}], ")"}]}]], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "2"]}]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          RowBox[{
           SuperscriptBox["y", "2"], " ", 
           SubscriptBox["\[Nu]", "3"]}]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["y", "2"]}], " ", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["y", "2"], " ", 
          SubsuperscriptBox["\[Nu]", "3", "2"]}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["y", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], "-", 
          SubscriptBox["\[Nu]", "3"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Nu]", "2", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "3"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Nu]", "1"], " ", 
          SubscriptBox["\[Nu]", "2"]}], "-", 
         SubsuperscriptBox["\[Nu]", "3", "2"]}], ")"}]}]], ",", "12"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.771122796993964*^9},ExpressionUUID->"8a6544c1-d57b-4f99-8da5-\
adf8ba58d8c3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"in", " ", "the", " ", "limit", " ", "y"}], "\[Rule]", "1"}], 
    ",", " ", 
    RowBox[{"each", " ", "term", " ", 
     RowBox[{"contributes", " ", "\\", "pm"}], " ", 
     RowBox[{"1", "/", "12"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Tally", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"(", 
       RowBox[{"JKChiGenus", "/.", 
        RowBox[{
         SubscriptBox["\[Theta]", "i_"], "\[RuleDelayed]", 
         RowBox[{
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["\[Nu]", "i"], "]"}], "/", "2"}], "/", 
          RowBox[{"Log", "[", "y", "]"}]}]}]}], ")"}], "]"}], "/.", 
     RowBox[{"y", "\[Rule]", "1"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.771122803750938*^9, 3.771122840833269*^9}, {
  3.771122993250827*^9, 
  3.771123018416689*^9}},ExpressionUUID->"39ea7082-d546-4370-8a3c-\
ff6ae05ded9b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "12"]}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "12"], ",", "162"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7711228068284388`*^9, 
  3.771122841172917*^9}},ExpressionUUID->"17bb83b5-3799-494e-8f5e-\
3c9d99f19832"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"JKVertexLabels", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "u1"}], ",", 
     RowBox[{"2", "\[Rule]", "v1"}], ",", 
     RowBox[{"3", "\[Rule]", "v1"}], ",", 
     RowBox[{"4", "\[Rule]", "v2"}], ",", 
     RowBox[{"5", "\[Rule]", "v3"}]}], "}"}]}], ";", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"DisplayFlagTree", "[", 
     RowBox[{"JKRelevantStableFlags", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "JKRelevantStableFlags", "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.771122512068667*^9},ExpressionUUID->"8ce343bc-5e1a-420d-8e0d-\
a9ca8ca56ad5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 3, 2}, {{{1, 2}, {1, 3}, {1, 4}, {5, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}, {0, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {3, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {1, 4}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 2, 3}, {{{1, 2}, {1, 3}, {4, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 3, 2}, {{{1, 2}, {1, 3}, {1, 4}, {5, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}, {0, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {3, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {1, 4}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 2, 3}, {{{1, 2}, {1, 3}, {4, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}]
             , ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}]
             , ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}]
             , ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 3, 2}, {{{1, 2}, {1, 3}, {1, 4}, {5, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}, {0, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {3, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {1, 4}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 2, 3}, {{{1, 2}, {1, 3}, {4, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 3, 2}, {{{1, 2}, {1, 3}, {1, 4}, {5, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}, {0, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {3, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {1, 4}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 2, 3}, {{{1, 2}, {1, 3}, {4, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}]
             , ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}]
             , ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 3, 2}, {{{1, 2}, {1, 3}, {1, 4}, {5, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}, {0, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {3, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {1, 4}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 2, 3}, {{{1, 2}, {1, 3}, {4, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 3, 2}, {{{1, 2}, {1, 3}, {1, 4}, {5, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}, {0, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 4, 3}, {{{1, 2}, {3, 4}, {3, 5}, {3, 2}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 4, 3}, {{{1, 2}, {3, 4}, {1, 5}, {1, 4}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 4]}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 4, 2, 3}, {{{1, 2}, {1, 3}, {4, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 5, 1, 3, 4}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 0}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{2, 4, 1, 3, 5}, {{{1, 2}, {3, 4}, {3, 5}, {1, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 2 -> $\
CellContext`v1, 1 -> $CellContext`u1}, VertexCoordinates -> {{0, 0}, {1, 
            Rational[3, 4]}, {0, 
            Rational[7, 8]}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 1.5}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 1.1875}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 5, 2, 3, 4}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 4] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 0}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 
            Rational[3, 4]}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], 
            InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.75}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 1], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 2]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{1, 4, 2, 3, 5}, {{{1, 2}, {3, 4}, {1, 5}, {3, 5}}, Null}, {
        EdgeLabels -> {
          DirectedEdge[1, 4] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[2, 3] -> Subscript[$CellContext`\[Theta], 3], 
           DirectedEdge[1, 5] -> Subscript[$CellContext`\[Theta], 2], 
           DirectedEdge[2, 5] -> Subscript[$CellContext`\[Theta], 1]}, 
         EdgeLabelStyle -> {
           Directive[
            RGBColor[1, 0, 0], Italic, 20]}, 
         VertexLabels -> {
          3 -> $CellContext`v1, 5 -> $CellContext`v3, 4 -> $CellContext`v2, 
           2 -> $CellContext`v1, 1 -> $CellContext`u1}, 
         VertexCoordinates -> {{0, 
            Rational[7, 8]}, {1, 
            Rational[3, 4]}, {0, 0}, {1, 
            Rational[3, 2]}, {1, 0}}}]]}, 
      TagBox[GraphicsGroupBox[{{
          {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
           Medium], {ArrowBox[{{0., 0.875}, {1., 0.75}}, 0.01842105263157895],
             InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.8125}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.875}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "2"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.4375}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 1.5}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "3"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.75}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}, {
            ArrowBox[{{0., 0.}, {1., 0.}}, 0.01842105263157895], InsetBox[
             StyleBox[
              SubscriptBox["\[Theta]", "1"],
              StripOnInput->False,
              LineColor->RGBColor[1, 0, 0],
              FrontFaceColor->RGBColor[1, 0, 0],
              BackFaceColor->RGBColor[1, 0, 0],
              GraphicsColor->RGBColor[1, 0, 0],
              FontSize->20,
              FontSlant->Italic,
              FontColor->RGBColor[1, 0, 0]], {0.5, 0.}, ImageScaled[{0.5, 0.5}],
             BaseStyle->"Graphics"]}}}, {
          {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
           0.7]}], {DiskBox[{0., 0.875}, 0.01842105263157895], 
            InsetBox["u1", 
             Offset[{2, 2}, {0.01842105263157895, 0.8934210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 0.75}, 0.01842105263157895], 
            InsetBox["v2", 
             Offset[{2, 2}, {1.018421052631579, 0.7684210526315789}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895],
             InsetBox["v1", 
             Offset[{2, 2}, {0.01842105263157895, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {
            DiskBox[{1., 1.5}, 0.01842105263157895], 
            InsetBox["v1", 
             Offset[{2, 2}, {1.018421052631579, 1.518421052631579}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895],
             InsetBox["v3", 
             Offset[{2, 2}, {1.018421052631579, 0.01842105263157895}], 
             ImageScaled[{0, 0}],
             BaseStyle->"Graphics"]}}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None]}], "}"}]], "Output",
 CellChangeTimes->{{3.77112249438903*^9, 
  3.771122516221476*^9}},ExpressionUUID->"182db5ea-6811-4cc9-8763-\
d0511a05f5de"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 862},
WindowMargins->{{96, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 190, 3, 125, "Title", "ExpressionUUID" -> \
"11816b1a-eba9-471a-ba6f-f0b9715d1f64"],
Cell[773, 27, 346, 8, 41, "Text", "ExpressionUUID" -> \
"be38471f-afdf-411e-8392-5ab921b77c5b"],
Cell[CellGroupData[{
Cell[1144, 39, 243, 6, 51, "Input", "ExpressionUUID" -> \
"c234fc8c-16e3-49ef-a64b-33e01f8d038e"],
Cell[1390, 47, 243, 4, 24, "Print", "ExpressionUUID" -> \
"43f9b8a8-c16b-4184-b65a-738de7763dd6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1670, 56, 1490, 46, 260, "Input", "ExpressionUUID" -> \
"198a1105-fb0c-4938-a09a-257aa678c02a"],
Cell[3163, 104, 1676, 36, 52, "Output", "ExpressionUUID" -> \
"2d531531-51e9-465d-8193-8d501ef65f75"],
Cell[4842, 142, 1515, 41, 115, "Output", "ExpressionUUID" -> \
"b3cbb73a-c53d-430d-b60a-72eeb11dd2b1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6394, 188, 216, 4, 35, "Subsection", "ExpressionUUID" -> \
"82cfc3f6-9173-4ba4-9b99-58e53e942ce7"],
Cell[CellGroupData[{
Cell[6635, 196, 563, 17, 51, "Input", "ExpressionUUID" -> \
"9a25b8f6-81a6-4d81-838c-aa5033a541e5"],
Cell[7201, 215, 886, 27, 51, "Output", "ExpressionUUID" -> \
"22d60a40-af88-4ed4-820d-00bd77f2a42b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8136, 248, 232, 4, 35, "Subsection", "ExpressionUUID" -> \
"6c65a787-8d01-4395-83cf-a69f0b606e96"],
Cell[CellGroupData[{
Cell[8393, 256, 170, 3, 31, "Input", "ExpressionUUID" -> \
"c181a47b-f323-4911-94cd-9fd2335da693"],
Cell[CellGroupData[{
Cell[8588, 263, 304, 7, 24, "Print", "ExpressionUUID" -> \
"e830ac81-b469-4132-8209-6279c73cf832"],
Cell[8895, 272, 442, 10, 24, "Print", "ExpressionUUID" -> \
"07041b07-4a1a-41f6-ace6-54f78444d4aa"]
}, Open  ]],
Cell[9352, 285, 2343, 76, 99, "Output", "ExpressionUUID" -> \
"632349de-f3ac-4916-b3a3-5193fceeaa21"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11732, 366, 304, 8, 31, "Input", "ExpressionUUID" -> \
"25465b00-f882-4280-9fee-8bdda1ad1c7d"],
Cell[12039, 376, 578, 17, 51, "Output", "ExpressionUUID" -> \
"77dd78d0-e21e-4e49-ad5a-dc68eda784ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12654, 398, 383, 9, 51, "Input", "ExpressionUUID" -> \
"5d701bf0-9b75-4184-bcde-c231ccc878a2"],
Cell[CellGroupData[{
Cell[13062, 411, 229, 4, 24, "Print", "ExpressionUUID" -> \
"8bbe80e8-6e72-47ed-a270-fe3795078da1"],
Cell[13294, 417, 2366, 74, 74, "Print", "ExpressionUUID" -> \
"749584e1-72ad-4cab-bc70-285bb7e28b00"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15709, 497, 747, 21, 51, "Input", "ExpressionUUID" -> \
"3c4fe801-62ed-45f5-a79b-87bbe13a63d9"],
Cell[16459, 520, 17642, 386, 233, "Output", "ExpressionUUID" -> \
"4272648e-6cea-4e57-afb3-ea630f6d86db"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34150, 912, 310, 5, 35, "Subsection", "ExpressionUUID" -> \
"0d99f949-d62c-4310-99e1-d61aa1b8b7c0"],
Cell[CellGroupData[{
Cell[34485, 921, 280, 6, 31, "Input", "ExpressionUUID" -> \
"ef7c617c-c872-4284-83aa-6584d150df49"],
Cell[CellGroupData[{
Cell[34790, 931, 351, 8, 24, "Print", "ExpressionUUID" -> \
"cac9ba8b-7b4d-475e-ab84-3e643a281a17"],
Cell[35144, 941, 956, 29, 40, "Print", "ExpressionUUID" -> \
"cdeb9b03-27e5-408a-a104-1c30aab32b28"],
Cell[36103, 972, 652, 16, 24, "Print", "ExpressionUUID" -> \
"49288de7-835d-4f28-9314-f0a9b042a786"],
Cell[36758, 990, 684, 17, 24, "Print", "ExpressionUUID" -> \
"888b8c98-442d-45d7-a088-4e1554613868"],
Cell[37445, 1009, 329, 8, 24, "Print", "ExpressionUUID" -> \
"980b33a6-d4d8-4b8e-9875-3f08e0e3f6e6"],
Cell[37777, 1019, 386, 11, 24, "Print", "ExpressionUUID" -> \
"1ca05ee5-d75a-4fc3-be89-f6faee9a07a5"],
Cell[38166, 1032, 418, 12, 24, "Print", "ExpressionUUID" -> \
"b4335e08-09c1-4cb4-99dd-e176083282ee"],
Cell[38587, 1046, 504, 12, 24, "Print", "ExpressionUUID" -> \
"e87f2c98-c7a6-43aa-8798-8fa4ba4e40e6"],
Cell[39094, 1060, 388, 11, 24, "Print", "ExpressionUUID" -> \
"b0abfa80-7469-4308-a3e6-cdf58e99b147"],
Cell[39485, 1073, 416, 12, 24, "Print", "ExpressionUUID" -> \
"5c2789fa-1feb-4ba3-acb5-8b88db06a185"]
}, Open  ]],
Cell[39916, 1088, 4796, 147, 189, "Output", "ExpressionUUID" -> \
"91062736-2093-4f6f-9ddc-266465cbc98d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44749, 1240, 306, 8, 31, "Input", "ExpressionUUID" -> \
"2d9a75e7-5efd-4a46-8010-d77aba6c52e1"],
Cell[45058, 1250, 2568, 79, 136, "Output", "ExpressionUUID" -> \
"11ade4f2-9bce-4bd2-a487-aaf93f89b009"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47663, 1334, 396, 11, 31, "Input", "ExpressionUUID" -> \
"e853196a-05f6-48e9-be79-9854b4f40295"],
Cell[48062, 1347, 483, 14, 47, "Output", "ExpressionUUID" -> \
"2bab2c8b-20de-47ff-8e93-63f555b6059a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48582, 1366, 721, 19, 51, "Input", "ExpressionUUID" -> \
"8c896799-98a1-42de-ab45-e50beaa62128"],
Cell[CellGroupData[{
Cell[49328, 1389, 331, 8, 24, "Print", "ExpressionUUID" -> \
"9c6f461e-5ec8-4dbf-9c9c-6bbdaef15c99"],
Cell[49662, 1399, 234, 4, 24, "Print", "ExpressionUUID" -> \
"0ac9a893-aa32-4245-b174-782788d415d9"],
Cell[49899, 1405, 2371, 74, 74, "Print", "ExpressionUUID" -> \
"1d8a8ebb-52aa-4225-bff2-51d5fef6f22e"],
Cell[52273, 1481, 359, 9, 24, "Print", "ExpressionUUID" -> \
"e457919f-4518-4bc2-9f47-ea6a8dc2b9e9"],
Cell[52635, 1492, 236, 4, 24, "Print", "ExpressionUUID" -> \
"9eecf1b4-7bd0-4f2b-a566-872adb37f1d4"],
Cell[52874, 1498, 2373, 74, 74, "Print", "ExpressionUUID" -> \
"2f6583a3-8ace-4442-a336-61ff14ca739b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55308, 1579, 334, 5, 35, "Subsection", "ExpressionUUID" -> \
"5dedb1a6-500c-4f24-af05-b1dde4a3c80b"],
Cell[CellGroupData[{
Cell[55667, 1588, 838, 23, 108, "Input", "ExpressionUUID" -> \
"9f22d712-3db5-4fcf-bb2c-235528a0e199"],
Cell[56508, 1613, 3469, 101, 319, "Output", "ExpressionUUID" -> \
"822f36cd-7c6d-4bfc-ab41-e416069d5c88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60014, 1719, 237, 7, 31, "Input", "ExpressionUUID" -> \
"a5112295-9c5b-426c-bbd2-bb5b83a06270"],
Cell[CellGroupData[{
Cell[60276, 1730, 286, 7, 24, "Print", "ExpressionUUID" -> \
"26e45682-1203-4174-9541-067ba009610b"],
Cell[60565, 1739, 427, 11, 24, "Print", "ExpressionUUID" -> \
"77f3e653-61b7-49c5-81c4-8595218ef8b4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61041, 1756, 307, 8, 31, "Input", "ExpressionUUID" -> \
"0b1f0607-3c42-4777-bd5e-c74403c58290"],
Cell[61351, 1766, 552, 16, 51, "Output", "ExpressionUUID" -> \
"05f3e759-35bc-4419-af37-3433b23b3f2b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61940, 1787, 587, 12, 51, "Input", "ExpressionUUID" -> \
"1c5d27e1-b872-41f1-a558-a86146286728"],
Cell[62530, 1801, 24292, 718, 603, "Output", "ExpressionUUID" -> \
"86eb9a2d-9a21-4f89-830d-f6dfb347cddb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86859, 2524, 750, 21, 54, "Input", "ExpressionUUID" -> \
"df98b11e-6417-4a17-a4b2-39be65b839c0"],
Cell[87612, 2547, 27409, 850, 678, "Output", "ExpressionUUID" -> \
"8a6544c1-d57b-4f99-8da5-adf8ba58d8c3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115058, 3402, 998, 27, 54, "Input", "ExpressionUUID" -> \
"39ea7082-d546-4370-8a3c-ff6ae05ded9b"],
Cell[116059, 3431, 373, 12, 47, "Output", "ExpressionUUID" -> \
"17bb83b5-3799-494e-8f5e-3c9d99f19832"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116469, 3448, 721, 21, 51, "Input", "ExpressionUUID" -> \
"8ce343bc-5e1a-420d-8e0d-a9ca8ca56ad5"],
Cell[117193, 3471, 788792, 17162, 10360, "Output", "ExpressionUUID" -> \
"182db5ea-6811-4cc9-8763-d0511a05f5de"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

