(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     69157,       2066]
NotebookOptionsPosition[     66676,       1996]
NotebookOutlinePosition[     67051,       2013]
CellTagsIndexPosition[     67008,       2010]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Kronecker quiver", "Title",
 CellChangeTimes->{{3.5663244994907923`*^9, 3.566324549302702*^9}, {
  3.566325401650366*^9, 3.5663254061910458`*^9}, {3.5663281662237787`*^9, 
  3.566328167637095*^9}, {3.566364982636116*^9, 
  3.566364986555542*^9}},ExpressionUUID->"784cbd9a-77bb-4f02-b5b1-\
2c19fc5dd333"],

Cell["\<\
J. Manschot, B. Pioline, A.Sen, Feb 2013. Updated for CoulombHiggs 2.0, Sep \
2013; for CoulombHiggs 6.0, Dec 2020\
\>", "Text",
 CellChangeTimes->{{3.589518029136827*^9, 3.5895180464931192`*^9}, {
  3.818224310625822*^9, 
  3.818224318651906*^9}},ExpressionUUID->"111a0223-ecdd-4a10-a44c-\
9403d826d8b3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "CoulombHiggs`"}]}], "Input",
 CellChangeTimes->{{3.566324560202894*^9, 3.566324565919025*^9}, {
  3.56632532246786*^9, 3.566325344994219*^9}, {3.567429150651526*^9, 
  3.5674291515012217`*^9}, {3.5694751893373117`*^9, 
  3.569475192711845*^9}},ExpressionUUID->"f99c4943-27c9-42cd-a9d3-\
43286e61d12a"],

Cell[BoxData["\<\"CoulombHiggs 6.0 - A package for evaluating quiver \
invariants\"\>"], "Print",
 CellChangeTimes->{3.570250560500848*^9, 3.570250675859223*^9, 
  3.5702508142940807`*^9, 3.570250921169189*^9, 3.570338286390943*^9, 
  3.585326352328389*^9, 3.5854507918671083`*^9, 3.5895180522582273`*^9, 
  3.818224321340085*^9},ExpressionUUID->"72d9c248-344d-4571-8f82-\
c25369105078"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "m", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$QuiverNoLoop", "=", "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$QuiverMultiplier", "=", "m"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$QuiverMultiplierAssumption", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Element]", "Integers"}], ",", 
     RowBox[{"m", ">", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.568655981943968*^9, 3.56865604126338*^9}, {
  3.5694231157772503`*^9, 3.569423116160769*^9}, {3.818224493919053*^9, 
  3.818224494579218*^9}, {3.818224531804216*^9, 
  3.818224532066132*^9}},ExpressionUUID->"e3fc5bfe-5765-4288-952c-\
1984b6272990"],

Cell[CellGroupData[{

Cell["Recorded results for low dimension vector", "Section",
 CellChangeTimes->{{3.566365799879808*^9, 
  3.566365810397958*^9}},ExpressionUUID->"d073923a-5190-45a9-9be2-\
ddeb0b1f9af7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"m", "+", "1"}], ")"}]}], 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", 
       RowBox[{"1", "-", "m"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", 
         RowBox[{"2", " ", "m"}]]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["y", "2"]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", "y_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["y", 
        RowBox[{"2", "-", 
         RowBox[{"2", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"2", " ", "m"}]]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["y", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", "y_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["y", 
        RowBox[{"2", "-", 
         RowBox[{"2", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"2", " ", "m"}]]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["y", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", 
       RowBox[{"3", "-", 
        RowBox[{"4", " ", "m"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", 
         RowBox[{"4", " ", "m"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
         SuperscriptBox["y", 
          RowBox[{"2", " ", "m"}]]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", " ", "m"}]]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
         SuperscriptBox["y", 
          RowBox[{"2", "+", 
           RowBox[{"2", " ", "m"}]}]]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
         SuperscriptBox["y", 
          RowBox[{"4", "+", 
           RowBox[{"2", " ", "m"}]}]]}]}], ")"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"m", "+", "1"}], ")"}]}], 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", 
       RowBox[{"3", "-", 
        RowBox[{"3", " ", "m"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "y"}], "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"y", "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", "2"]}], "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "m"]}], ")"}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "4"]}], ")"}]}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["y", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", "6"]}], "+", 
        SuperscriptBox["y", "8"], "+", 
        SuperscriptBox["y", "10"], "+", 
        SuperscriptBox["y", 
         RowBox[{"12", "-", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"6", "-", 
          RowBox[{"2", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"8", "-", 
          RowBox[{"2", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"10", "-", 
          RowBox[{"2", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"12", "-", 
          RowBox[{"2", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"2", " ", "m"}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"4", " ", "m"}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"2", "+", 
          RowBox[{"2", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"4", "+", 
          RowBox[{"2", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"6", "+", 
          RowBox[{"2", " ", "m"}]}]]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "4"]}], ")"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", "y_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["y", 
        RowBox[{"8", "-", 
         RowBox[{"6", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"6", " ", "m"}]], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}], "4"], "-", 
       RowBox[{
        SuperscriptBox["y", 
         RowBox[{"2", " ", "m"}]], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["y", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["y", "4"]}], "+", 
          SuperscriptBox["y", "6"]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["y", 
         RowBox[{"2", "-", 
          RowBox[{"2", " ", "m"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["y", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["y", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["y", "6"]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["y", "4"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["y", 
        RowBox[{"5", "-", 
         RowBox[{"8", " ", "m"}]}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["y", 
           RowBox[{"2", " ", "m"}]]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["y", "14"]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"8", " ", "m"}]], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", " ", "m"}]]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"12", " ", "m"}]], "+", 
         SuperscriptBox["y", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "m"}], ")"}]}]], "+", 
         SuperscriptBox["y", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "m"}], ")"}]}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"7", "+", "m"}], ")"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", "+", 
            RowBox[{"4", " ", "m"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", "+", 
            RowBox[{"4", " ", "m"}]}]]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", "+", 
            RowBox[{"4", " ", "m"}]}]]}], "-", 
         SuperscriptBox["y", 
          RowBox[{"14", "+", 
           RowBox[{"4", " ", "m"}]}]], "-", 
         SuperscriptBox["y", 
          RowBox[{"2", "+", 
           RowBox[{"6", " ", "m"}]}]], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"6", " ", "m"}]}]]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", "+", 
            RowBox[{"6", " ", "m"}]}]]}], "-", 
         SuperscriptBox["y", 
          RowBox[{"2", "+", 
           RowBox[{"8", " ", "m"}]}]], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", "+", 
            RowBox[{"8", " ", "m"}]}]]}]}], ")"}]}], ")"}]}], "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "5"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "4"]}], ")"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["y", 
       RowBox[{"6", "-", 
        RowBox[{"10", " ", "m"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "y"}], "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"y", "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", "2"]}], "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "m"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", "16"]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"14", " ", "m"}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", "m"}], ")"}]}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"4", "+", 
          RowBox[{"10", " ", "m"}]}]], "+", 
        RowBox[{
         SuperscriptBox["y", 
          RowBox[{"12", " ", "m"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["y", "4"]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["y", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"6", "+", "m"}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["y", "4"]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["y", 
          RowBox[{"8", " ", "m"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["y", "2"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["y", "4"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["y", "6"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["y", "8"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["y", "10"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["y", "12"]}], "+", 
           SuperscriptBox["y", "14"]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["y", 
          RowBox[{"2", "+", 
           RowBox[{"6", " ", "m"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SuperscriptBox["y", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "y"}], ")"}], " ", "y"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["y", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "y", "+", 
              SuperscriptBox["y", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              SuperscriptBox["y", "4"], "+", 
              SuperscriptBox["y", "6"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "6"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "4"], "+", 
        SuperscriptBox["y", "6"], "+", 
        SuperscriptBox["y", "8"]}], ")"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", "y_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "y"}], ")"}], 
      RowBox[{"5", "-", 
       RowBox[{"9", " ", "m"}]}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", "2"], "-", 
        SuperscriptBox["y", 
         RowBox[{"2", " ", "m"}]]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", 
         RowBox[{"2", " ", "m"}]]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["y", 
        RowBox[{"2", " ", "m"}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"4", " ", "m"}]]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["y", "8"]}], "+", 
       SuperscriptBox["y", 
        RowBox[{"4", " ", "m"}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"6", " ", "m"}]], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"6", "+", 
          RowBox[{"2", " ", "m"}]}]]}], "-", 
       SuperscriptBox["y", 
        RowBox[{"8", "+", 
         RowBox[{"2", " ", "m"}]}]], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"2", "+", 
          RowBox[{"4", " ", "m"}]}]]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "2"]}], ")"}], "5"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["y", "4"]}], ")"}], "2"]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["y", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{"21", " ", 
         SuperscriptBox["y", "4"]}], "-", 
        RowBox[{"39", " ", 
         SuperscriptBox["y", "6"]}], "-", 
        RowBox[{"52", " ", 
         SuperscriptBox["y", "8"]}], "-", 
        RowBox[{"52", " ", 
         SuperscriptBox["y", "10"]}], "-", 
        RowBox[{"39", " ", 
         SuperscriptBox["y", "12"]}], "-", 
        RowBox[{"21", " ", 
         SuperscriptBox["y", "14"]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["y", "16"]}], "-", 
        SuperscriptBox["y", "18"], "+", 
        SuperscriptBox["y", 
         RowBox[{"18", "-", 
          RowBox[{"12", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"8", "-", 
          RowBox[{"6", " ", "m"}]}]], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"10", "-", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{"12", "-", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{"14", "-", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", 
          RowBox[{"16", "-", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"18", "-", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"6", "-", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"8", "-", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"10", "-", 
           RowBox[{"4", " ", "m"}]}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"12", "-", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"14", "-", 
           RowBox[{"4", " ", "m"}]}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"16", "-", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"18", "-", 
          RowBox[{"4", " ", "m"}]}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"2", "-", 
          RowBox[{"2", " ", "m"}]}]], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"15", " ", 
         SuperscriptBox["y", 
          RowBox[{"6", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", 
          RowBox[{"8", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["y", 
          RowBox[{"10", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"30", " ", 
         SuperscriptBox["y", 
          RowBox[{"12", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"21", " ", 
         SuperscriptBox["y", 
          RowBox[{"14", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["y", 
          RowBox[{"16", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", 
          RowBox[{"18", "-", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", 
          RowBox[{"2", " ", "m"}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"4", " ", "m"}]], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"6", " ", "m"}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"12", " ", "m"}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", "m"}], ")"}]}]], "+", 
        RowBox[{"26", " ", 
         SuperscriptBox["y", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"5", "+", "m"}], ")"}]}]]}], "+", 
        RowBox[{"15", " ", 
         SuperscriptBox["y", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"6", "+", "m"}], ")"}]}]]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", "m"}], ")"}]}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"8", "+", "m"}], ")"}]}]], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["y", 
          RowBox[{"2", "+", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"21", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", "+", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"30", " ", 
         SuperscriptBox["y", 
          RowBox[{"6", "+", 
           RowBox[{"2", " ", "m"}]}]]}], "+", 
        RowBox[{"32", " ", 
         SuperscriptBox["y", 
          RowBox[{"8", "+", 
           RowBox[{"2", " ", "m"}]}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"2", "+", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", "+", 
           RowBox[{"4", " ", "m"}]}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"6", "+", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"8", "+", 
           RowBox[{"4", " ", "m"}]}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"10", "+", 
          RowBox[{"4", " ", "m"}]}]], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", 
          RowBox[{"2", "+", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", "+", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{"6", "+", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"8", "+", 
           RowBox[{"6", " ", "m"}]}]]}], "-", 
        SuperscriptBox["y", 
         RowBox[{"10", "+", 
          RowBox[{"6", " ", "m"}]}]]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "6"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "4"]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["y", "4"]}], ")"}], "2"]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"m", "+", "1"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["y", 
         RowBox[{"33", "-", 
          RowBox[{"15", " ", "m"}]}]]}], "+", 
       SuperscriptBox["y", 
        RowBox[{"25", "-", 
         RowBox[{"9", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"27", "-", 
         RowBox[{"9", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"29", "-", 
         RowBox[{"9", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"31", "-", 
         RowBox[{"9", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"33", "-", 
         RowBox[{"9", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"17", "-", 
         RowBox[{"7", " ", "m"}]}]], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["y", 
         RowBox[{"21", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "+", 
       RowBox[{"7", " ", 
        SuperscriptBox["y", 
         RowBox[{"23", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["y", 
         RowBox[{"25", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["y", 
         RowBox[{"27", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "+", 
       RowBox[{"7", " ", 
        SuperscriptBox["y", 
         RowBox[{"29", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["y", 
         RowBox[{"31", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"33", "-", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       SuperscriptBox["y", 
        RowBox[{"15", "-", 
         RowBox[{"5", " ", "m"}]}]], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["y", 
         RowBox[{"17", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["y", 
         RowBox[{"21", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"13", " ", 
        SuperscriptBox["y", 
         RowBox[{"23", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"14", " ", 
        SuperscriptBox["y", 
         RowBox[{"25", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["y", 
         RowBox[{"27", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["y", 
         RowBox[{"29", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["y", 
         RowBox[{"31", "-", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       SuperscriptBox["y", 
        RowBox[{"33", "-", 
         RowBox[{"5", " ", "m"}]}]], "-", 
       SuperscriptBox["y", 
        RowBox[{"11", "-", 
         RowBox[{"3", " ", "m"}]}]], "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["y", 
         RowBox[{"13", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"13", " ", 
        SuperscriptBox["y", 
         RowBox[{"15", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"25", " ", 
        SuperscriptBox["y", 
         RowBox[{"17", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"38", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"47", " ", 
        SuperscriptBox["y", 
         RowBox[{"21", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"49", " ", 
        SuperscriptBox["y", 
         RowBox[{"23", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"43", " ", 
        SuperscriptBox["y", 
         RowBox[{"25", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"31", " ", 
        SuperscriptBox["y", 
         RowBox[{"27", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"18", " ", 
        SuperscriptBox["y", 
         RowBox[{"29", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["y", 
         RowBox[{"31", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"33", "-", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"9", "-", "m"}]]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["y", 
         RowBox[{"11", "-", "m"}]]}], "+", 
       RowBox[{"34", " ", 
        SuperscriptBox["y", 
         RowBox[{"13", "-", "m"}]]}], "+", 
       RowBox[{"69", " ", 
        SuperscriptBox["y", 
         RowBox[{"15", "-", "m"}]]}], "+", 
       RowBox[{"108", " ", 
        SuperscriptBox["y", 
         RowBox[{"17", "-", "m"}]]}], "+", 
       RowBox[{"140", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "-", "m"}]]}], "+", 
       RowBox[{"150", " ", 
        SuperscriptBox["y", 
         RowBox[{"21", "-", "m"}]]}], "+", 
       RowBox[{"136", " ", 
        SuperscriptBox["y", 
         RowBox[{"23", "-", "m"}]]}], "+", 
       RowBox[{"102", " ", 
        SuperscriptBox["y", 
         RowBox[{"25", "-", "m"}]]}], "+", 
       RowBox[{"63", " ", 
        SuperscriptBox["y", 
         RowBox[{"27", "-", "m"}]]}], "+", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", 
         RowBox[{"29", "-", "m"}]]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["y", 
         RowBox[{"31", "-", "m"}]]}], "+", 
       SuperscriptBox["y", 
        RowBox[{"33", "-", "m"}]], "+", 
       RowBox[{"14", " ", 
        SuperscriptBox["y", 
         RowBox[{"5", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", "m"}], ")"}]}]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"7", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", "m"}], ")"}]}]]}], "+", 
       RowBox[{"43", " ", 
        SuperscriptBox["y", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", "m"}], ")"}]}]]}], "+", 
       SuperscriptBox["y", 
        RowBox[{"5", " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", "m"}], ")"}]}]], "-", 
       SuperscriptBox["y", 
        RowBox[{"7", "+", "m"}]], "+", 
       RowBox[{"38", " ", 
        SuperscriptBox["y", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"7", "+", "m"}], ")"}]}]]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["y", 
         RowBox[{"9", "+", "m"}]]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["y", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"9", "+", "m"}], ")"}]}]]}], "-", 
       RowBox[{"29", " ", 
        SuperscriptBox["y", 
         RowBox[{"11", "+", "m"}]]}], "-", 
       RowBox[{"63", " ", 
        SuperscriptBox["y", 
         RowBox[{"13", "+", "m"}]]}], "-", 
       RowBox[{"102", " ", 
        SuperscriptBox["y", 
         RowBox[{"15", "+", "m"}]]}], "-", 
       RowBox[{"136", " ", 
        SuperscriptBox["y", 
         RowBox[{"17", "+", "m"}]]}], "-", 
       RowBox[{"150", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "+", "m"}]]}], "-", 
       RowBox[{"140", " ", 
        SuperscriptBox["y", 
         RowBox[{"21", "+", "m"}]]}], "-", 
       RowBox[{"108", " ", 
        SuperscriptBox["y", 
         RowBox[{"23", "+", "m"}]]}], "-", 
       RowBox[{"69", " ", 
        SuperscriptBox["y", 
         RowBox[{"25", "+", "m"}]]}], "-", 
       RowBox[{"34", " ", 
        SuperscriptBox["y", 
         RowBox[{"27", "+", "m"}]]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["y", 
         RowBox[{"29", "+", "m"}]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"31", "+", "m"}]]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"7", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["y", 
         RowBox[{"9", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"18", " ", 
        SuperscriptBox["y", 
         RowBox[{"11", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"31", " ", 
        SuperscriptBox["y", 
         RowBox[{"13", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"49", " ", 
        SuperscriptBox["y", 
         RowBox[{"17", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"47", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"25", " ", 
        SuperscriptBox["y", 
         RowBox[{"23", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       RowBox[{"13", " ", 
        SuperscriptBox["y", 
         RowBox[{"25", "+", 
          RowBox[{"3", " ", "m"}]}]]}], "+", 
       SuperscriptBox["y", 
        RowBox[{"29", "+", 
         RowBox[{"3", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"7", "+", 
         RowBox[{"5", " ", "m"}]}]], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["y", 
         RowBox[{"9", "+", 
          RowBox[{"5", " ", "m"}]}]]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["y", 
         RowBox[{"11", "+", 
          RowBox[{"5", " ", "m"}]}]]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["y", 
         RowBox[{"13", "+", 
          RowBox[{"5", " ", "m"}]}]]}], "+", 
       RowBox[{"13", " ", 
        SuperscriptBox["y", 
         RowBox[{"17", "+", 
          RowBox[{"5", " ", "m"}]}]]}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "+", 
          RowBox[{"5", " ", "m"}]}]]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["y", 
         RowBox[{"21", "+", 
          RowBox[{"5", " ", "m"}]}]]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["y", 
         RowBox[{"23", "+", 
          RowBox[{"5", " ", "m"}]}]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", 
         RowBox[{"7", "+", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["y", 
         RowBox[{"9", "+", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["y", 
         RowBox[{"11", "+", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["y", 
         RowBox[{"13", "+", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["y", 
         RowBox[{"15", "+", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["y", 
         RowBox[{"17", "+", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["y", 
         RowBox[{"19", "+", 
          RowBox[{"7", " ", "m"}]}]]}], "-", 
       SuperscriptBox["y", 
        RowBox[{"23", "+", 
         RowBox[{"7", " ", "m"}]}]], "-", 
       SuperscriptBox["y", 
        RowBox[{"7", "+", 
         RowBox[{"9", " ", "m"}]}]], "-", 
       SuperscriptBox["y", 
        RowBox[{"9", "+", 
         RowBox[{"9", " ", "m"}]}]], "-", 
       SuperscriptBox["y", 
        RowBox[{"11", "+", 
         RowBox[{"9", " ", "m"}]}]], "-", 
       SuperscriptBox["y", 
        RowBox[{"13", "+", 
         RowBox[{"9", " ", "m"}]}]], "-", 
       SuperscriptBox["y", 
        RowBox[{"15", "+", 
         RowBox[{"9", " ", "m"}]}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"7", "+", 
         RowBox[{"15", " ", "m"}]}]]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "7"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "4"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["y", "4"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["y", "4"], "+", 
         SuperscriptBox["y", "6"], "+", 
         SuperscriptBox["y", "8"]}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["y", 
        RowBox[{"7", "-", 
         RowBox[{"16", " ", "m"}]}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["y", "2"], "-", 
          SuperscriptBox["y", 
           RowBox[{"2", " ", "m"}]], "+", 
          SuperscriptBox["y", 
           RowBox[{"4", " ", "m"}]], "-", 
          SuperscriptBox["y", 
           RowBox[{"2", "+", 
            RowBox[{"2", " ", "m"}]}]]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["y", "20"]}], "-", 
         SuperscriptBox["y", 
          RowBox[{"10", " ", "m"}]], "-", 
         SuperscriptBox["y", 
          RowBox[{"12", " ", "m"}]], "+", 
         SuperscriptBox["y", 
          RowBox[{"16", " ", "m"}]], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"18", " ", "m"}]]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"20", " ", "m"}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"22", " ", "m"}]]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"24", " ", "m"}]], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "m"}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"12", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "m"}], ")"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"14", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "m"}], ")"}]}]]}], "-", 
         SuperscriptBox["y", 
          RowBox[{"16", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "m"}], ")"}]}]], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "m"}], ")"}]}]]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "m"}], ")"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", "m"}], ")"}]}]]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"4", "+", "m"}], ")"}]}]]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"5", "+", "m"}], ")"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"9", "+", "m"}], ")"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"20", "+", 
            RowBox[{"2", " ", "m"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"18", "+", 
            RowBox[{"4", " ", "m"}]}]]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"8", "+", 
           RowBox[{"6", " ", "m"}]}]], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", "+", 
            RowBox[{"6", " ", "m"}]}]]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"16", "+", 
            RowBox[{"6", " ", "m"}]}]]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"20", "+", 
            RowBox[{"6", " ", "m"}]}]]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"4", "+", 
           RowBox[{"8", " ", "m"}]}]], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "+", 
         RowBox[{"10", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["y", 
           RowBox[{"12", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["y", 
           RowBox[{"14", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"18", "+", 
            RowBox[{"8", " ", "m"}]}]]}], "-", 
         SuperscriptBox["y", 
          RowBox[{"20", "+", 
           RowBox[{"8", " ", "m"}]}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", "+", 
            RowBox[{"10", " ", "m"}]}]]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"10", " ", "m"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", "+", 
            RowBox[{"10", " ", "m"}]}]]}], "-", 
         SuperscriptBox["y", 
          RowBox[{"8", "+", 
           RowBox[{"10", " ", "m"}]}]], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["y", 
           RowBox[{"12", "+", 
            RowBox[{"10", " ", "m"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"14", "+", 
            RowBox[{"10", " ", "m"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"16", "+", 
            RowBox[{"10", " ", "m"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", "+", 
            RowBox[{"12", " ", "m"}]}]]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"12", " ", "m"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", "+", 
            RowBox[{"12", " ", "m"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", "+", 
            RowBox[{"12", " ", "m"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"14", "+", 
            RowBox[{"12", " ", "m"}]}]]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["y", 
           RowBox[{"16", "+", 
            RowBox[{"12", " ", "m"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"18", "+", 
            RowBox[{"12", " ", "m"}]}]]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"20", "+", 
           RowBox[{"12", " ", "m"}]}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"14", " ", "m"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", "+", 
            RowBox[{"14", " ", "m"}]}]]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", "+", 
            RowBox[{"14", " ", "m"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", "+", 
            RowBox[{"14", " ", "m"}]}]]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"12", "+", 
           RowBox[{"14", " ", "m"}]}]], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["y", 
           RowBox[{"16", "+", 
            RowBox[{"14", " ", "m"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"18", "+", 
            RowBox[{"14", " ", "m"}]}]]}], "+", 
         SuperscriptBox["y", 
          RowBox[{"20", "+", 
           RowBox[{"14", " ", "m"}]}]], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", "+", 
            RowBox[{"16", " ", "m"}]}]]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"16", " ", "m"}]}]]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["y", 
           RowBox[{"6", "+", 
            RowBox[{"16", " ", "m"}]}]]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", "+", 
            RowBox[{"16", " ", "m"}]}]]}], "-", 
         RowBox[{"10", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", "+", 
            RowBox[{"16", " ", "m"}]}]]}], "-", 
         RowBox[{"8", " ", 
          SuperscriptBox["y", 
           RowBox[{"12", "+", 
            RowBox[{"16", " ", "m"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"14", "+", 
            RowBox[{"16", " ", "m"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", "+", 
            RowBox[{"18", " ", "m"}]}]]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"18", " ", "m"}]}]]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"8", "+", 
            RowBox[{"18", " ", "m"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"10", "+", 
            RowBox[{"18", " ", "m"}]}]]}], "-", 
         SuperscriptBox["y", 
          RowBox[{"12", "+", 
           RowBox[{"18", " ", "m"}]}]], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", "+", 
            RowBox[{"20", " ", "m"}]}]]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["y", 
           RowBox[{"4", "+", 
            RowBox[{"20", " ", "m"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", 
           RowBox[{"2", "+", 
            RowBox[{"22", " ", "m"}]}]]}]}], ")"}]}], ")"}]}], "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "7"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "4"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["y", "4"]}], ")"}], "2"]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.566365508426589*^9, 3.5663655134651833`*^9}, {
  3.566365671160995*^9, 3.566365689924806*^9}, {3.566365748360732*^9, 
  3.5663657525855513`*^9}, {3.5664094154158163`*^9, 3.566409457138565*^9}, {
  3.566410181681253*^9, 3.566410208936659*^9}, {3.5664110802419357`*^9, 
  3.566411096877408*^9}, {3.567146968073351*^9, 3.5671469732972803`*^9}, {
  3.5686565160396757`*^9, 3.5686565220152903`*^9}, {3.5688687694772177`*^9, 
  3.568868775341476*^9}, {3.568869180337418*^9, 3.568869180963689*^9}, {
  3.569422514460106*^9, 3.56942251450445*^9}, {3.5694225627180862`*^9, 
  3.569422563004038*^9}, {3.569422709186384*^9, 
  3.569422737951707*^9}},ExpressionUUID->"7391dfe4-53e1-40d3-b9ae-\
f5e086cf3e39"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evaluate the Poincare polynomial", "Section",
 CellChangeTimes->{{3.5663257400631237`*^9, 
  3.566325761342157*^9}},ExpressionUUID->"dd25d1fe-ad47-4add-81b7-\
49afd7c6f378"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cvec", "=", 
   RowBox[{"-", 
    RowBox[{"AttractorFI", "[", 
     RowBox[{"Mat", ",", "Nvec"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzl1Ik2EcBfDlR2s2IXNFVLZVN/qyvEli68P1bipGlkzUcpGsDVtpksQu
urA5hcxylOnWFkQMIbtwsEFeDD9CqhtXBKLZBw51UM2HTclVKmT1nP/F4ce5
OHD2W65XNaRJJJICHtg/yQ6f6WWiT3W2CKqXPUY4nlNVA1VHWR38Yc8wQa/G
Wg8TWalL0F2iaIR1nqVrUBBSbbRvkjvhZe23h3DNHSd/FhjHYKsrTO7Wb3sH
g8n19/D+xNYFC3f4WDb5W3ZiwMp9Oasjo4lTm1zcpSNWsvrjDg28Ha3UQpO6
RwcdE4Nk9/JiKTQMZ5VRN5oLY/g37yPne95EavqYuHo+SnZMdW7u5ob+PiBf
yPxXoNdib4LFJw0tULFQQjav6DYi3H7pBTL2b1eu1M3E8Lk80ry3uBM6tTfJ
cOXO1i3c0vQKJ8ywNeyTcYsudpC9c7eUX7ia8jYyIBHuwMzJQ6Qhpf+wx8NE
7fMKUrWhjMNP8SSD+YE5aeARE6cL12RwxfFUgPKgn7TFQs9yvUyszxsdIJWN
o2R6FzlTmx2Bdkc+GX9r+wq7+trJRflB1QEfE09n6kn/bNlVOJMsJ4XP7feg
7/ETF1S8/jUGtw+tk6/ufjcFbyTE439GzHA1Td0MQznjLfA/x11OXw==
  
  "],ExpressionUUID->"522f795c-5f34-4e47-ad24-4a9711f63ef0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QCoulomb", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"CoulombBranchFormula", "[", 
     RowBox[{"Mat", ",", "Cvec", ",", "Nvec"}], "]"}], ",", 
    "$QuiverMultiplierAssumption"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.567016029942596*^9, 3.5670160310425043`*^9}, {
   3.567016173470949*^9, 3.567016181165941*^9}, {3.567016518214642*^9, 
   3.567016545677002*^9}, {3.567274241395352*^9, 3.567274247905613*^9}, {
   3.567274506076002*^9, 3.567274506867218*^9}, {3.5676922102420883`*^9, 
   3.567692210441121*^9}, 3.567702344733656*^9, 3.5677025361595373`*^9, {
   3.567702691905326*^9, 3.567702699463328*^9}, 3.567702760966723*^9, {
   3.5677028593827333`*^9, 3.567702860349798*^9}, {3.567702901590885*^9, 
   3.567702902146818*^9}, {3.56783702592771*^9, 3.567837026502062*^9}, {
   3.56865605873682*^9, 3.568656066086918*^9}, {3.5686566952005157`*^9, 
   3.5686567024882936`*^9}, {3.56886864875856*^9, 3.568868649278404*^9}, {
   3.569422616564973*^9, 3.56942261910984*^9}, {3.5694227828012047`*^9, 
   3.569422784001871*^9}, {3.569423906547161*^9, 3.569423909794601*^9}, {
   3.5853263631670303`*^9, 3.585326363438569*^9}, {3.8182244431373053`*^9, 
   3.8182244440857887`*^9}},ExpressionUUID->"af656bfc-0351-453d-bf2f-\
fe46d47ce663"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["y", 
     RowBox[{"3", "-", 
      RowBox[{"4", " ", "m"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["y", 
       RowBox[{"4", " ", "m"}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["y", "4"]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
       SuperscriptBox["y", 
        RowBox[{"2", " ", "m"}]]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["y", 
        RowBox[{"4", " ", "m"}]]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
       SuperscriptBox["y", 
        RowBox[{"2", "+", 
         RowBox[{"2", " ", "m"}]}]]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
       SuperscriptBox["y", 
        RowBox[{"4", "+", 
         RowBox[{"2", " ", "m"}]}]]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{{3.568656334924946*^9, 3.568656355232972*^9}, 
   3.5686564094012547`*^9, {3.568656465056652*^9, 3.568656482529662*^9}, 
   3.568656526577283*^9, {3.5686567196478863`*^9, 3.568656727478834*^9}, 
   3.568725479785421*^9, 3.568725882636139*^9, {3.568868650228702*^9, 
   3.568868657422326*^9}, 3.568868734842298*^9, 3.568868838205249*^9, {
   3.569422596676341*^9, 3.569422619671194*^9}, {3.569422785005048*^9, 
   3.569422789099992*^9}, 3.569423179753892*^9, 3.5694232322815857`*^9, 
   3.5694234459228153`*^9, 3.569423856815523*^9, {3.5694238890980587`*^9, 
   3.5694239103233147`*^9}, 3.5694752405873938`*^9, 3.570207987246978*^9, {
   3.5702505699210663`*^9, 3.5702505720692387`*^9}, 3.570338292940164*^9, {
   3.5853263653370247`*^9, 3.585326382074057*^9}, 3.589518060083009*^9, {
   3.818224335097804*^9, 3.818224359368225*^9}, 3.818224444888318*^9, 
   3.818224519516692*^9},ExpressionUUID->"ab584125-d394-4445-a40d-\
5cb8efed3958"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QHiggs", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"HiggsBranchFormula", "[", 
     RowBox[{"Mat", ",", "Cvec", ",", "Nvec"}], "]"}], ",", 
    "$QuiverMultiplierAssumption"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.569422814106914*^9, 3.569422821094733*^9}, {
   3.569423084585252*^9, 3.569423085327283*^9}, {3.5694238723177767`*^9, 
   3.569423900172325*^9}, {3.58532642683747*^9, 3.585326426997217*^9}, 
   3.818224417076985*^9},ExpressionUUID->"ee9ce324-1b14-42fa-8917-\
e1f2be29ab5a"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["y", "2"]}], ")"}], "2"]}]], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], " ", 
   SuperscriptBox["y", 
    RowBox[{"3", "-", 
     RowBox[{"6", " ", "m"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["y", 
      RowBox[{"4", " ", "m"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "y"}], ")"}], 
       RowBox[{"2", " ", "m"}]], " ", 
      SuperscriptBox["y", "4"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
      SuperscriptBox["y", 
       RowBox[{"4", " ", "m"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"], " ", 
      SuperscriptBox["y", 
       RowBox[{"6", " ", "m"}]]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
      SuperscriptBox["y", 
       RowBox[{"2", "+", 
        RowBox[{"4", " ", "m"}]}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
      SuperscriptBox["y", 
       RowBox[{"4", "+", 
        RowBox[{"4", " ", "m"}]}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.569422815966909*^9, 3.569422821619431*^9}, 
   3.569422986063382*^9, {3.569423085961545*^9, 3.56942309318145*^9}, {
   3.569423124353736*^9, 3.569423149024375*^9}, 3.569423181081962*^9, {
   3.569423228707547*^9, 3.5694232373328257`*^9}, {3.5694234509055758`*^9, 
   3.569423462728283*^9}, {3.56942385784592*^9, 3.569423910957724*^9}, 
   3.569475241691956*^9, 3.57020799075147*^9, 3.570250584013606*^9, 
   3.585326427481121*^9, 3.589518061443268*^9, {3.8182243644223137`*^9, 
   3.818224446018229*^9}, 
   3.81822452083003*^9},ExpressionUUID->"2dec9f33-f9dc-4007-9e56-\
784c1ac5c4fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"QCoulomb", "-", 
    RowBox[{"OmR", "[", 
     RowBox[{"Nvec", ",", "y"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Element]", "Integers"}], ",", 
     RowBox[{"y", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.567016570914033*^9, 3.567016584508479*^9}, {
   3.569422793217951*^9, 3.5694227953349733`*^9}, 3.569423164801033*^9, 
   3.569423917640231*^9},ExpressionUUID->"e4b8ba17-3c30-4ab7-84a5-\
93b0da391915"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.5670165849957943`*^9, {3.567016776350559*^9, 3.567016803536681*^9}, {
   3.567146996785112*^9, 3.567147007155047*^9}, {3.567272909612483*^9, 
   3.567272957819066*^9}, 3.567274513524239*^9, {3.567702044248125*^9, 
   3.5677020493226*^9}, 3.567702271409181*^9, {3.56865649454193*^9, 
   3.568656527472486*^9}, {3.568656721188003*^9, 3.56865672934831*^9}, 
   3.56872588563316*^9, {3.5694225982731028`*^9, 3.569422620582197*^9}, 
   3.569422795855815*^9, {3.569423161440551*^9, 3.569423182275663*^9}, 
   3.569423238553849*^9, {3.569423882850375*^9, 3.5694239208700523`*^9}, 
   3.56947524332539*^9, 3.570207993423059*^9, 3.585326430493903*^9, 
   3.589518062954892*^9, 3.8182243739860983`*^9, {3.818224425734747*^9, 
   3.8182244469427137`*^9}, 
   3.8182245215994787`*^9},ExpressionUUID->"7948f406-1773-4e8d-b58c-\
9b8df4132684"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"QHiggs", "-", 
    RowBox[{"OmR", "[", 
     RowBox[{"Nvec", ",", "y"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Element]", "Integers"}], ",", 
     RowBox[{"y", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.569422836895166*^9, 3.569422837696515*^9}, 
   3.56942316833442*^9, 
   3.569423919752252*^9},ExpressionUUID->"61fb61b1-6719-48da-bc22-\
509122bf6280"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.5694228385534077`*^9, {3.569423168825775*^9, 3.5694231828931932`*^9}, 
   3.569423239171356*^9, {3.569423883488263*^9, 3.569423921470458*^9}, 
   3.569475244193585*^9, 3.570207994761166*^9, 3.585326433890149*^9, 
   3.5895180639504128`*^9, 3.818224377318946*^9, {3.8182244267942677`*^9, 
   3.818224447663766*^9}, 
   3.81822452248428*^9},ExpressionUUID->"a5f9c755-4a18-48eb-94f3-\
1278f79cf70b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"QCoulomb", "-", 
       RowBox[{"OmR", "[", 
        RowBox[{"Nvec", ",", "y"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.566327036175734*^9, 3.56632705106171*^9}, {
   3.566329241941512*^9, 3.566329319521072*^9}, {3.566329354992567*^9, 
   3.5663293612325573`*^9}, {3.5663652044425163`*^9, 3.56636520752941*^9}, {
   3.5663652591764717`*^9, 3.566365305310602*^9}, 3.566365827648973*^9, {
   3.566366035138361*^9, 3.566366039320635*^9}, {3.566409471385085*^9, 
   3.5664094911654787`*^9}, {3.5664102347954884`*^9, 3.5664102351308804`*^9}, 
   3.5670165544451323`*^9, {3.569422799514497*^9, 3.569422801439601*^9}, 
   3.569423172712214*^9},ExpressionUUID->"7ac266f3-c109-4cdc-9d00-\
35b65c9c3e98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.566327045432914*^9, 3.566327051481593*^9}, {
   3.566329245430238*^9, 3.566329320036087*^9}, {3.566329356103743*^9, 
   3.566329361559737*^9}, {3.566365260426862*^9, 3.56636530562294*^9}, {
   3.566365361924453*^9, 3.5663653961789007`*^9}, {3.566365437346199*^9, 
   3.5663654599529037`*^9}, 3.566365535627228*^9, 3.5663656599962587`*^9, 
   3.566365742616884*^9, {3.566365822719521*^9, 3.566365828130616*^9}, {
   3.566409485673746*^9, 3.566409491697297*^9}, 3.566410240564842*^9, 
   3.566411067837307*^9, 3.566411102365738*^9, {3.566494132683133*^9, 
   3.566494150188216*^9}, 3.566494188381378*^9, 3.5664942368131104`*^9, 
   3.5666702100867653`*^9, 3.567016555199753*^9, {3.567016777796563*^9, 
   3.567016806883638*^9}, 3.567147010137994*^9, 3.5672745147147827`*^9, 
   3.567702050591278*^9, 3.568656530927353*^9, 3.568656731268879*^9, 
   3.5687258871684237`*^9, 3.5694226216814537`*^9, 3.5694228020664062`*^9, {
   3.569423172870984*^9, 3.569423184141737*^9}, 3.569423242285906*^9, 
   3.569475244882625*^9, 3.570207996961412*^9, 3.585326435571434*^9, 
   3.5895180654027042`*^9, 
   3.818224448805607*^9},ExpressionUUID->"eeae4d69-3ce7-42c6-afe9-\
bc80e6e387f6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 607},
WindowMargins->{{Automatic, 83}, {Automatic, 1}},
ShowSelection->True,
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 309, 5, 77, "Title", "ExpressionUUID" -> \
"784cbd9a-77bb-4f02-b5b1-2c19fc5dd333"],
Cell[891, 29, 315, 7, 26, "Text", "ExpressionUUID" -> \
"111a0223-ecdd-4a10-a44c-9403d826d8b3"],
Cell[CellGroupData[{
Cell[1231, 40, 459, 10, 51, "Input", "ExpressionUUID" -> \
"f99c4943-27c9-42cd-a9d3-43286e61d12a"],
Cell[1693, 52, 387, 6, 24, "Print", "ExpressionUUID" -> \
"72d9c248-344d-4571-8f82-c25369105078"]
}, Open  ]],
Cell[2095, 61, 978, 26, 108, "Input", "ExpressionUUID" -> \
"e3fc5bfe-5765-4288-952c-1984b6272990"],
Cell[CellGroupData[{
Cell[3098, 91, 186, 3, 68, "Section", "ExpressionUUID" -> \
"d073923a-5190-45a9-9be2-ddeb0b1f9af7"],
Cell[3287, 96, 50438, 1562, 1422, "Input", "ExpressionUUID" -> \
"7391dfe4-53e1-40d3-b9ae-f5e086cf3e39"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53762, 1663, 179, 3, 68, "Section", "ExpressionUUID" -> \
"dd25d1fe-ad47-4add-81b7-49afd7c6f378"],
Cell[53944, 1668, 1050, 23, 51, "Input", "ExpressionUUID" -> \
"522f795c-5f34-4e47-ad24-4a9711f63ef0"],
Cell[CellGroupData[{
Cell[55019, 1695, 1278, 21, 31, "Input", "ExpressionUUID" -> \
"af656bfc-0351-453d-bf2f-fe46d47ce663"],
Cell[56300, 1718, 2548, 69, 57, "Output", "ExpressionUUID" -> \
"ab584125-d394-4445-a40d-5cb8efed3958"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58885, 1792, 531, 11, 31, "Input", "ExpressionUUID" -> \
"ee9ce324-1b14-42fa-8917-e1f2be29ab5a"],
Cell[59419, 1805, 2485, 76, 77, "Output", "ExpressionUUID" -> \
"2dec9f33-f9dc-4007-9e56-784c1ac5c4fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61941, 1886, 516, 13, 31, "Input", "ExpressionUUID" -> \
"e4b8ba17-3c30-4ab7-84a5-93b0da391915"],
Cell[62460, 1901, 882, 14, 31, "Output", "ExpressionUUID" -> \
"7948f406-1773-4e8d-b58c-9b8df4132684"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63379, 1920, 465, 13, 31, "Input", "ExpressionUUID" -> \
"61fb61b1-6719-48da-bc22-509122bf6280"],
Cell[63847, 1935, 449, 8, 31, "Output", "ExpressionUUID" -> \
"a5f9c755-4a18-48eb-94f3-1278f79cf70b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64333, 1948, 1003, 21, 31, "Input", "ExpressionUUID" -> \
"7ac266f3-c109-4cdc-9d00-35b65c9c3e98"],
Cell[65339, 1971, 1297, 20, 31, "Output", "ExpressionUUID" -> \
"eeae4d69-3ce7-42c6-afe9-bc80e6e387f6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

