(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    255920,       7456]
NotebookOptionsPosition[    251781,       7343]
NotebookOutlinePosition[    252137,       7359]
CellTagsIndexPosition[    252094,       7356]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Non-Abelian 3-node quivers", "Title",
 CellChangeTimes->{{3.5663244994907923`*^9, 3.566324549302702*^9}, {
  3.566325401650366*^9, 3.5663254061910458`*^9}, {3.5663281662237787`*^9, 
  3.566328167637095*^9}},ExpressionUUID->"44013ac8-bf55-4b15-a225-\
bf122abbf38a"],

Cell["\<\
J. Manschot, B. Pioline, A.Sen, Feb 2013. Updated for CoulombHiggs 2.0, Sep \
2013; Updated for CoulombHiggs 6.0, Dec 2020\
\>", "Text",
 CellChangeTimes->{{3.589518029136827*^9, 3.5895180464931192`*^9}, {
  3.818224717913631*^9, 
  3.818224725848477*^9}},ExpressionUUID->"1eb4ff90-0422-4969-a01b-\
4eebd3955371"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "CoulombHiggs`"}]}], "Input",
 CellChangeTimes->{{3.566324560202894*^9, 3.566324565919025*^9}, {
  3.56632532246786*^9, 3.566325344994219*^9}, {3.568724358080986*^9, 
  3.568724364512698*^9}, {3.568724516070455*^9, 3.5687245167180843`*^9}, {
  3.569475284909253*^9, 
  3.569475287469247*^9}},ExpressionUUID->"9b1a5b66-c34c-4b8f-be54-\
9fbe88c7dd9e"],

Cell[BoxData["\<\"CoulombHiggs 6.0 - A package for evaluating quiver \
invariants\"\>"], "Print",
 CellChangeTimes->{3.56872436492402*^9, 3.5687245172603407`*^9, 
  3.5687259484757*^9, 3.5694752881625233`*^9, 3.570208021601766*^9, 
  3.57025113606365*^9, 3.570251607225005*^9, 3.570254569208932*^9, 
  3.585326463037692*^9, 3.589518665035756*^9, 
  3.818224582989571*^9},ExpressionUUID->"37df4785-99cc-4c20-b2c3-\
8c2fa462132c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Choosing the DSZ matrix, dimension vector and FI terms", "Section",
 CellChangeTimes->{{3.566327129488984*^9, 3.5663271418727627`*^9}, {
  3.566328184600851*^9, 
  3.56632820081273*^9}},ExpressionUUID->"24fe8327-c52f-44db-8d97-\
de753841205c"],

Cell["\<\
Evaluate the cell corresponding to the dimension vector, and proceed to \
section \[OpenCurlyDoubleQuote]Evaluate the Poincare polynomial\
\[CloseCurlyDoubleQuote].
The result of the computation is recorded below as OmR[Nvec], with \
corresponding list of  H-factors as soH[Nvec]\
\>", "Text",
 CellChangeTimes->{{3.566327188031907*^9, 3.566327376442587*^9}, {
   3.5686548729898033`*^9, 3.568654890237124*^9}, 
   3.570208043830353*^9},ExpressionUUID->"01b5f7c7-3d16-41da-b85f-\
f8047abfbca7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rank (1,1,1)", "Subsection"]], "Section",
 CellChangeTimes->{{3.5663254642796717`*^9, 3.566325467582808*^9}, {
  3.5663274625214787`*^9, 
  3.566327463136525*^9}},ExpressionUUID->"3404a405-dc6b-4182-9895-\
e520c326bd11"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aa", "=", "3"}], ";", 
  RowBox[{"bb", "=", "2"}], ";", 
  RowBox[{"cc", "=", "3"}], ";", 
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ";", 
  RowBox[{"Cvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "8"}], "/", "10"}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], "/", "10"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", 
   RowBox[{"kk", 
    RowBox[{"(", 
     RowBox[{"aa", "+", "bb", "-", "cc"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"soH", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CoulombH", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
     "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["y", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OmR", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], "]"}], "=", 
    RowBox[{
     RowBox[{"OmS", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}], "]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", "k"}]}], ")"}], "/", "2"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"y", "^", 
            RowBox[{"(", "k", ")"}]}], "+", 
           RowBox[{"y", "^", 
            RowBox[{"(", 
             RowBox[{"-", "k"}], ")"}]}], "-", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "^", "k"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"y", "^", 
            RowBox[{"(", "k", ")"}]}], "+", 
           RowBox[{"y", "^", 
            RowBox[{"(", 
             RowBox[{"-", "k"}], ")"}]}], "-", "y", "-", 
           RowBox[{"1", "/", "y"}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"y", "-", 
         RowBox[{"1", "/", "y"}]}], ")"}], "^", "2"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"aa", "+", 
     RowBox[{
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"bb", "-", "cc"}], ")"}]}]}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cc", "-", "bb"}], ")"}], 
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "+", 
     RowBox[{"2", "bb"}], "-", "aa"}], ">", "0"}], ",", 
   RowBox[{"bb", "<", "cc"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "<", "0"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.565591003165935*^9, 3.5655910170692663`*^9}, {
   3.565591327283873*^9, 3.5655913299527473`*^9}, {3.5656391483182793`*^9, 
   3.565639148661241*^9}, {3.565875094001368*^9, 3.565875094356048*^9}, {
   3.565875135035803*^9, 3.5658751738832903`*^9}, {3.565875310161331*^9, 
   3.565875348384059*^9}, {3.565875383454648*^9, 3.565875416406636*^9}, {
   3.565875566152923*^9, 3.5658755670318403`*^9}, 3.565892198024341*^9, {
   3.565898166506373*^9, 3.56589823784781*^9}, {3.56589896023801*^9, 
   3.565898960366879*^9}, {3.5662816356480923`*^9, 3.5662816408880167`*^9}, {
   3.566306345504056*^9, 3.566306390649296*^9}, 3.5663064566077433`*^9, {
   3.56630654908429*^9, 3.566306549300848*^9}, {3.566306632514926*^9, 
   3.566306676505961*^9}, 3.5663111609478807`*^9, {3.566325472030575*^9, 
   3.566325478946241*^9}, 3.566325654676331*^9, {3.566327380942327*^9, 
   3.566327387899036*^9}, {3.566328079635263*^9, 3.566328082799906*^9}, {
   3.566670288432866*^9, 3.5666702957537518`*^9}, {3.567191707272153*^9, 
   3.567191764182273*^9}, {3.567701601361475*^9, 3.567701612006193*^9}, {
   3.56770165861799*^9, 3.5677016593359118`*^9}, {3.5686543561715517`*^9, 
   3.56865435747084*^9}, 3.570208053857996*^9, {3.585326475818347*^9, 
   3.58532647591434*^9}, 
   3.585450824659267*^9},ExpressionUUID->"faa29396-6266-40a7-a96b-\
82d1dbbc5752"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.566306677692688*^9, 3.5663111643695583`*^9, {3.566325808022533*^9, 
   3.56632581271751*^9}, 3.566326358428472*^9, 3.566326973190362*^9, 
   3.566327404341877*^9, 3.566327640109256*^9, {3.566327689534854*^9, 
   3.5663276975894747`*^9}, 3.5663289364368877`*^9, 3.566670299216117*^9, 
   3.566670410647029*^9, 3.566670661460774*^9, {3.567148139230006*^9, 
   3.56714815594635*^9}, 3.567153590605844*^9, 3.5671908009311132`*^9, {
   3.56719175853339*^9, 3.567191764445258*^9}, {3.5671939611201363`*^9, 
   3.567193966830163*^9}, 3.5671942896796427`*^9, {3.567273066759776*^9, 
   3.5672730853705587`*^9}, {3.567692253312467*^9, 3.567692280782078*^9}, 
   3.567692777405731*^9, 3.567694040733165*^9, 3.567701191536541*^9, 
   3.567701280199911*^9, 3.5677016157655993`*^9, 3.568539016870247*^9, 
   3.568573096589202*^9, 3.568573237281172*^9, 3.568573636457374*^9, 
   3.568654404186883*^9, {3.568654626500648*^9, 3.5686546505730467`*^9}, 
   3.5686547729597893`*^9, 3.5687190065603523`*^9, 3.568724370066456*^9, 
   3.5687245213032637`*^9, 3.5687259509214*^9, 3.570208054219057*^9, 
   3.570251138223241*^9, 3.585326465070217*^9, 3.585326610860512*^9, 
   3.585450860317731*^9, 3.5895186720328007`*^9, 
   3.818224587063501*^9},ExpressionUUID->"66e0e157-8b3f-4ff3-bfa3-\
47f7883dc753"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rank (1,1,2)", "Subsection"]], "Section",
 CellChangeTimes->{{3.5663254642796717`*^9, 3.566325467582808*^9}, {
  3.5663274625214787`*^9, 
  3.566327472959866*^9}},ExpressionUUID->"286d456b-a783-48c1-b73f-\
625c95b35ab5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aa", "=", "3"}], ";", 
  RowBox[{"bb", "=", "2"}], ";", 
  RowBox[{"cc", "=", "3"}], ";", 
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "2"}], "}"}]}], ";", 
  RowBox[{"Cvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "8"}], "/", "10"}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "10"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", 
   RowBox[{"kk", 
    RowBox[{"(", 
     RowBox[{"aa", "+", 
      RowBox[{
       RowBox[{"Nvec", "[", 
        RowBox[{"[", "3", "]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"bb", "-", "cc"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"soH", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "2"}], "}"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "8"], " ", "kk", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "2"}], "}"}], "]"}], "=", 
   RowBox[{
    RowBox[{"OmS", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "2"}], "}"}], "]"}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"(", " ", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "^", "k"}]}], ")"}], "/", "2"}], 
          " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"y", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "k"}], "+", "1"}], ")"}]}], "-", 
            RowBox[{"y", "^", 
             RowBox[{"(", 
              RowBox[{"k", "-", "1"}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"1", "/", "4"}], 
             RowBox[{"(", 
              RowBox[{"k", "-", "1"}], ")"}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"y", "+", 
                RowBox[{"1", "/", "y"}]}], ")"}], "^", "2"}], 
             RowBox[{"(", 
              RowBox[{"y", "-", 
               RowBox[{"1", "/", "y"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"1", "/", "4"}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"k", "/", "2"}], ")"}]}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"y", "-", 
                RowBox[{"1", "/", "y"}]}], ")"}], "^", "3"}]}]}], ")"}]}], 
         "\[IndentingNewLine]", "+", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "^", "k"}]}], ")"}], "/", "2"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"y", "^", 
             RowBox[{"(", 
              RowBox[{"k", "-", "1"}], ")"}]}], "-", 
            RowBox[{"y", "^", 
             RowBox[{"(", 
              RowBox[{"1", "-", "k"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"1", "/", "2"}], 
             RowBox[{"(", 
              RowBox[{"k", "-", "1"}], ")"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"y", "^", "2"}], "-", 
               RowBox[{"1", "/", 
                RowBox[{"y", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
       ")"}], "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"y", "-", 
         RowBox[{"1", "/", "y"}]}], ")"}], "^", "3"}]}], "/", 
     RowBox[{"(", 
      RowBox[{"y", "+", 
       RowBox[{"1", "/", "y"}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"aa", "+", 
     RowBox[{
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"bb", "-", "cc"}], ")"}]}]}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cc", "-", "bb"}], ")"}], 
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "+", 
     RowBox[{"2", "bb"}], "-", "aa"}], ">", "0"}], ",", 
   RowBox[{"bb", "<", "cc"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "<", "0"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.566327507131289*^9, 3.566327516988062*^9}, {
   3.566327649636023*^9, 3.566327649949778*^9}, {3.566328087165289*^9, 
   3.5663280894733763`*^9}, {3.567148626748127*^9, 3.567148628058681*^9}, {
   3.567148840177009*^9, 3.567148849205969*^9}, {3.568654369249022*^9, 
   3.56865436965591*^9}, {3.568654986268159*^9, 3.568654999929922*^9}, 
   3.5702081640200453`*^9, {3.58532648586275*^9, 3.585326485918626*^9}, 
   3.585450826389124*^9},ExpressionUUID->"26906044-0bf2-456d-bd7e-\
27bdf0eaa1f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.566327650797771*^9, 3.566327877322616*^9, 
  3.56632893846871*^9, 3.567148568417905*^9, 3.5671486493391733`*^9, 
  3.56714884955053*^9, 3.567193624795014*^9, 3.567193895420096*^9, 
  3.567194216019722*^9, 3.5672732547313423`*^9, 3.567692400321294*^9, 
  3.567692433313299*^9, 3.567701339513204*^9, 3.5685414265638313`*^9, 
  3.5685731435101633`*^9, 3.568573687108096*^9, 3.568653277957389*^9, 
  3.568654435035788*^9, 3.568654842742124*^9, 3.568654912791333*^9, 
  3.570208169530505*^9, 3.570251609974081*^9, 3.585326640374939*^9, 
  3.5895187405972757`*^9, 3.818224603383547*^9, 
  3.8182246417473993`*^9},ExpressionUUID->"6d6066db-c544-4da9-aed2-\
af6781ccc471"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rank (1,1,3)", "Subsection"]], "Section",
 CellChangeTimes->{{3.5663254642796717`*^9, 3.566325467582808*^9}, {
  3.5663274625214787`*^9, 3.566327472959866*^9}, {3.5663275320806913`*^9, 
  3.5663275321909513`*^9}},ExpressionUUID->"ef3ff091-982a-4f9c-8681-\
96b855eea079"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aa", "=", "4"}], ";", 
  RowBox[{"bb", "=", "2"}], ";", 
  RowBox[{"cc", "=", "3"}], ";", 
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "3"}], "}"}]}], ";", 
  RowBox[{"Cvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "7"}], "/", "10"}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "10"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", 
   RowBox[{"kk", 
    RowBox[{"(", 
     RowBox[{"aa", "+", 
      RowBox[{
       RowBox[{"Nvec", "[", 
        RowBox[{"[", "3", "]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"bb", "-", "cc"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"soH", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "3"}], "}"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "8"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "18"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"kk", " ", "\[Pi]"}], "3"], "]"}]}], 
          RowBox[{"1", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], " ", "y"}]}]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"2", " ", "kk", " ", "\[Pi]"}], "3"], "]"}]}], 
          RowBox[{"1", "+", "y", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", "kk"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "-", 
         FractionBox["kk", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"kk", " ", "\[Pi]"}], "2"], "]"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y_"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "192"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["kk", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "y"}], ")"}], " ", "y"}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]]}], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SuperscriptBox["kk", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", "y"}], ")"}], "2"]}], "-", 
             RowBox[{"y", " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", "y"}], ")"}]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "4"]]}], ")"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OmR", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], "]"}], "=", 
    RowBox[{
     FractionBox["1", "576"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"96", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "kk"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["y", 
            RowBox[{"-", "kk"}]], "+", 
           SuperscriptBox["y", "kk"]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "y"], "-", "y"}], ")"}], "4"]], "-", 
       FractionBox[
        RowBox[{"288", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "y"}], ")"}], 
          RowBox[{"4", "-", "kk"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", 
            RowBox[{"2", " ", "kk"}]]}], ")"}]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{"192", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "y"}], ")"}], 
          RowBox[{"4", "-", "kk"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", 
            RowBox[{"2", " ", "kk"}]]}], ")"}]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["y", "4"]}], ")"}]}]], "+", 
       RowBox[{"32", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"2", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
              "3"]], "+", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
              "3"]]}], 
           RowBox[{"1", "-", "y", "+", 
            SuperscriptBox["y", "2"]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], "3"]], "+", 
            
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"5", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
              "3"]]}], 
           RowBox[{"1", "+", "y", "+", 
            SuperscriptBox["y", "2"]}]]}], ")"}]}], "+", 
       RowBox[{"18", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
             RowBox[{"-", "kk"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}]], "+", 
          RowBox[{"kk", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"-", "1"}], ")"}], "kk"]}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "-", 
             FractionBox["2", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ")"}]}], 
       "+", 
       RowBox[{"3", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SuperscriptBox["kk", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "+", 
               RowBox[{"4", " ", "y"}], "-", 
               SuperscriptBox["y", "2"]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{"4", " ", "y"}], "-", 
              SuperscriptBox["y", "2"], "+", 
              RowBox[{
               SuperscriptBox["kk", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "+", "y"}], ")"}], "2"]}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "4"]]}], ")"}]}], "+", 
       RowBox[{"576", " ", 
        RowBox[{"OmS", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "3"}], "}"}], "]"}]}]}], ")"}]}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"expected", " ", "answer"}], ",", " ", 
    RowBox[{"up", " ", "to", " ", "positive", " ", "powers", " ", "of", " ", 
     RowBox[{"y", ":"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OmPol", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"Nvec", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}], "=", 
    RowBox[{
     RowBox[{"OmS", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", 
        RowBox[{"Nvec", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"k", "+", 
         RowBox[{"Nvec", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "+", "1"}], ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"y", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k"}], "+", 
           RowBox[{
            RowBox[{"Nvec", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "^", "2"}], "+", "1"}], ")"}]}], 
        "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"y", "^", "2"}]}], ")"}], "^", "2"}]}], "/", 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"1", "-", 
          RowBox[{"y", "^", 
           RowBox[{"(", 
            RowBox[{"2", "i"}], ")"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "2", ",", 
           RowBox[{"Nvec", "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "]"}]}]}]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"aa", "+", 
     RowBox[{
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"bb", "-", "cc"}], ")"}]}]}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cc", "-", "bb"}], ")"}], 
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "+", 
     RowBox[{"2", "bb"}], "-", "aa"}], ">", "0"}], ",", 
   RowBox[{"bb", "<", "cc"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ",", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Nvec", "[", 
        RowBox[{"[", "i", "]"}], "]"}], " ", 
       RowBox[{"Cvec", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "\[Equal]", "0"}]}], 
  "}"}]}], "Input",
 CellChangeTimes->{{3.56632758787152*^9, 3.566327601075683*^9}, 
   3.566327921682687*^9, {3.566328092254767*^9, 3.566328096199533*^9}, {
   3.56714863717242*^9, 3.5671486385097113`*^9}, {3.5671488067088137`*^9, 
   3.567148833971428*^9}, {3.567190012480814*^9, 3.567190014414963*^9}, {
   3.567190196584605*^9, 3.56719019872919*^9}, {3.5671903744319887`*^9, 
   3.567190381402823*^9}, {3.567190420652326*^9, 3.567190433526935*^9}, {
   3.5685737357991743`*^9, 3.5685737365527267`*^9}, {3.5686544445133963`*^9, 
   3.568654485262486*^9}, {3.5686550134570093`*^9, 3.568655014076397*^9}, 
   3.568655061329541*^9, 3.570208217894318*^9, {3.585326494963581*^9, 
   3.585326500589603*^9}, {3.585326707391103*^9, 3.5853267074482803`*^9}, {
   3.5854508282792253`*^9, 
   3.585450829444097*^9}},ExpressionUUID->"9084add1-a875-43d7-92d3-\
b198f4e07d48"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.568654485764597*^9, 3.568655015847826*^9, 
  3.585326656691818*^9, 
  3.585326707878374*^9},ExpressionUUID->"70393c3a-8c27-4dfc-a77a-\
9284c2c4fcbb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rank (1,1,4)", "Subsection"]], "Section",
 CellChangeTimes->{{3.5663254642796717`*^9, 3.566325467582808*^9}, {
  3.5663274625214787`*^9, 3.566327472959866*^9}, {3.5663275320806913`*^9, 
  3.5663275321909513`*^9}, {3.5663281146560926`*^9, 3.566328116086904*^9}, {
  3.566328287987131*^9, 
  3.566328289833646*^9}},ExpressionUUID->"799f5485-9c3c-490d-b26a-\
b3dad097375e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aa", "=", "5"}], ";", 
  RowBox[{"bb", "=", "2"}], ";", 
  RowBox[{"cc", "=", "3"}], ";", 
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "4"}], "}"}]}], ";", 
  RowBox[{"Cvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "6"}], "/", "10"}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "10"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", 
   RowBox[{"kk", 
    RowBox[{"(", 
     RowBox[{"aa", "+", 
      RowBox[{
       RowBox[{"Nvec", "[", 
        RowBox[{"[", "3", "]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"bb", "-", "cc"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"soH", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "4"}], "}"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"7", " ", "kk"}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "18"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"20", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
             "3"]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"40", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
             "3"]]}], 
          RowBox[{"1", "-", "y", "+", 
           SuperscriptBox["y", "2"]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"10", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
             "3"]], "+", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"50", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
             "3"]]}], 
          RowBox[{"1", "+", "y", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "64"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            FractionBox[
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "kk"}], ")"}]}], "4"]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ImaginaryI]", "kk"]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "4"}]], "-", "y"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"1", "/", "4"}]], " ", "y"}]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            FractionBox[
             RowBox[{"3", "-", "kk"}], "4"]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ImaginaryI]", "kk"]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "4"}]], "+", "y"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"1", "/", "4"}]], " ", "y"}]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            FractionBox[
             RowBox[{"3", "+", "kk"}], "4"]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"3", " ", "kk"}]]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"3", "/", "4"}]], "-", "y"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"3", "/", "4"}]], " ", "y"}]}], ")"}]}]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            RowBox[{
             RowBox[{"-", 
              FractionBox["3", "4"]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "kk"}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"3", " ", "kk"}]]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"3", "/", "4"}]], "+", "y"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"3", "/", "4"}]], " ", "y"}]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
            RowBox[{"-", "kk"}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"2", " ", "kk"}]]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["3", "8"], " ", "kk", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "72"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", "kk"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", "kk"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            RowBox[{
             FractionBox["1", "3"], "+", "kk"}]], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["2", "3"]}], " ", "\[ImaginaryI]", " ", "kk", " ", 
             "\[Pi]"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"4", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
               "3"]]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "3"}]]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"2", "/", "3"}]]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "3"}]], "+", "y"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"1", "/", "3"}]], " ", "y"}]}], ")"}]}]], "+", 
         FractionBox[
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            RowBox[{
             FractionBox["2", "3"], "+", "kk"}]], " ", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], "3"]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["2", "3"]}], " ", "\[ImaginaryI]", " ", "kk", " ",
                "\[Pi]"}]]}], ")"}]}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"1", "/", "3"}]]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"2", "/", "3"}]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"2", "/", "3"}]], "+", "y"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], 
               RowBox[{"2", "/", "3"}]], " ", "y"}]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            RowBox[{
             FractionBox["1", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", "kk"}]}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{
               RowBox[{"2", " ", "kk"}], "/", "3"}]]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"2", "/", "3"}]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", "y", "+", 
             SuperscriptBox["y", "2"]}], ")"}]}]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            FractionBox[
             RowBox[{"2", "+", "kk"}], "3"]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{
               RowBox[{"4", " ", "kk"}], "/", "3"}]]}], ")"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "3"}]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "y", "+", 
             SuperscriptBox["y", "2"]}], ")"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "256"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", "kk"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", "kk"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
            RowBox[{"-", "kk"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "y"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "kk", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "y"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "kk", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["y", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["y", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["kk", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}]}], 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"]}]]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "256"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
             RowBox[{"-", "kk"}]], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}]]}], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"2", " ", "kk"}]]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["kk", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"3", " ", "y"}], "+", 
                SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["kk", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", "y"}], ")"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"3", " ", "y"}], "+", 
                SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "4"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
         "}"}], ",", "y"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "+", 
              RowBox[{
               SuperscriptBox["kk", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "+", 
              RowBox[{"14", " ", "y"}], "-", 
              RowBox[{"4", " ", 
               SuperscriptBox["y", "2"]}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["kk", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"1", "+", "y"}], ")"}], "2"]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{"7", " ", "y"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "4"]]}], ")"}]}], "4608"]}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OmR", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "4"}], "}"}], "]"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"5", "-", "kk"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["y", 
           RowBox[{"-", "kk"}]]}], "+", 
         SuperscriptBox["y", "kk"]}], ")"}]}], 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "y"]}], "+", "y"}], ")"}], "5"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"3", "-", "kk"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["y", 
           RowBox[{"-", "kk"}]]}], "+", 
         SuperscriptBox["y", "kk"]}], ")"}]}], 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SuperscriptBox["y", "2"]]}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"3", "-", "kk"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["y", 
           RowBox[{"-", "kk"}]]}], "+", 
         SuperscriptBox["y", "kk"]}], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "y"]}], "+", "y"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox["y", "3"]]}], "+", 
         SuperscriptBox["y", "3"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"4", "-", "kk"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["y", 
          RowBox[{"-", "kk"}]], "+", 
         SuperscriptBox["y", "kk"]}], ")"}]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "y"]}], "+", "y"}], ")"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox["y", "2"]]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"2", "-", "kk"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["y", 
          RowBox[{"-", "kk"}]], "+", 
         SuperscriptBox["y", "kk"]}], ")"}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox["y", "4"]]}], "+", 
         SuperscriptBox["y", "4"]}], ")"}]}]], "+", 
     RowBox[{
      FractionBox["1", "64"], " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
        FractionBox["2", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           FractionBox[
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "kk"}], ")"}]}], "4"]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ImaginaryI]", "kk"]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"1", "/", "4"}]], "-", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "4"}]], " ", "y"}]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           FractionBox[
            RowBox[{"3", "-", "kk"}], "4"]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ImaginaryI]", "kk"]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"1", "/", "4"}]], "+", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "4"}]], " ", "y"}]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           FractionBox[
            RowBox[{"3", "+", "kk"}], "4"]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"3", " ", "kk"}]]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"3", "/", "4"}]], "-", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"3", "/", "4"}]], " ", "y"}]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{
            RowBox[{"-", 
             FractionBox["3", "4"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "kk"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"3", " ", "kk"}]]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"3", "/", "4"}]], "+", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"3", "/", "4"}]], " ", "y"}]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
           RowBox[{"-", "kk"}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"2", " ", "kk"}]]}], ")"}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}]]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "72"], " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], " ", "kk"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", "kk"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{"6", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{
            FractionBox["1", "3"], "+", "kk"}]], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["2", "3"]}], " ", "\[ImaginaryI]", " ", "kk", " ", 
            "\[Pi]"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], 
              "3"]]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"2", "/", "3"}]]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"1", "/", "3"}]], "+", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "3"}]], " ", "y"}]}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"6", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{
            FractionBox["2", "3"], "+", "kk"}]], " ", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "kk", " ", "\[Pi]"}], "3"]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["2", "3"]}], " ", "\[ImaginaryI]", " ", "kk", " ", 
              "\[Pi]"}]]}], ")"}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"1", "/", "3"}]]}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "3"}]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "3"}]], "+", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"2", "/", "3"}]], " ", "y"}]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{
            FractionBox["1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "kk"}]}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{
              RowBox[{"2", " ", "kk"}], "/", "3"}]]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", "/", "3"}]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "y", "+", 
            SuperscriptBox["y", "2"]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           FractionBox[
            RowBox[{"2", "+", "kk"}], "3"]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{
              RowBox[{"4", " ", "kk"}], "/", "3"}]]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"1", "/", "3"}]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "y", "+", 
            SuperscriptBox["y", "2"]}], ")"}]}]]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "256"], " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], " ", "kk"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", "kk"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
           RowBox[{"-", "kk"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["\[ImaginaryI]", 
                RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "y"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["\[ImaginaryI]", 
                RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "kk", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["\[ImaginaryI]", 
                RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "y"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["\[ImaginaryI]", 
                RowBox[{"2", " ", "kk"}]]}], ")"}], " ", "kk", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "256"], " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "\[ImaginaryI]"}], ")"}], 
            RowBox[{"-", "kk"}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"2", " ", "kk"}]]}], ")"}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["kk", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"3", " ", "y"}], "+", 
               SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["kk", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "y"}], ")"}], "2"]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "y"}], "+", 
               SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "y"}], ")"}], "4"]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{"kk", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             RowBox[{
              SuperscriptBox["kk", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "+", 
             RowBox[{"14", " ", "y"}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["y", "2"]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["kk", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "y"}], ")"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{"7", " ", "y"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["y", "2"]}]}], ")"}]}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "4"]]}], ")"}]}], "2304"], "+", 
     RowBox[{"OmS", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "4"}], "}"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"up", " ", "to", " ", "positive", " ", "powers", " ", "of", " ", 
    RowBox[{"y", ":"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OmPol", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"Nvec", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}], "=", 
    RowBox[{
     RowBox[{"OmS", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", 
        RowBox[{"Nvec", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"k", "+", 
         RowBox[{"Nvec", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "+", "1"}], ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"y", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k"}], "+", 
           RowBox[{
            RowBox[{"Nvec", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "^", "2"}], "+", "1"}], ")"}]}], 
        "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"y", "^", "2"}]}], ")"}], "^", "2"}]}], "/", 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"1", "-", 
          RowBox[{"y", "^", 
           RowBox[{"(", 
            RowBox[{"2", "i"}], ")"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "2", ",", 
           RowBox[{"Nvec", "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "]"}]}]}]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"aa", "+", 
     RowBox[{
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"bb", "-", "cc"}], ")"}]}]}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cc", "-", "bb"}], ")"}], 
      RowBox[{"Nvec", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "+", 
     RowBox[{"2", "bb"}], "-", "aa"}], ">", "0"}], ",", 
   RowBox[{"bb", "<", "cc"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
   RowBox[{
    RowBox[{"Cvec", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ",", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Nvec", "[", 
        RowBox[{"[", "i", "]"}], "]"}], " ", 
       RowBox[{"Cvec", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}], "\[Equal]", "0"}]}], 
  "}"}]}], "Input",
 CellChangeTimes->{{3.5663283205437727`*^9, 3.5663283340707607`*^9}, {
   3.5671486435416813`*^9, 3.567148645204052*^9}, 3.567149326486414*^9, 
   3.567163614824513*^9, 3.5671717298115463`*^9, {3.567189151707877*^9, 
   3.567189182949252*^9}, {3.567190026442668*^9, 3.567190027985623*^9}, {
   3.567190214293242*^9, 3.567190216803791*^9}, {3.5686544984117813`*^9, 
   3.568654520383747*^9}, {3.568655221036569*^9, 3.5686552231434727`*^9}, 
   3.5702082359063787`*^9, {3.5853265147552834`*^9, 3.585326519103345*^9}, {
   3.5854508310623417`*^9, 
   3.585450832496212*^9}},ExpressionUUID->"8691f96e-cfa9-4e62-9b8e-\
660f27193b81"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.568654521324232*^9, 
  3.568655075236648*^9},ExpressionUUID->"ae86ce07-3344-455f-a3e1-\
1d02274bfb8f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rank (1,2,2)", "Subsection"]], "Section",
 CellChangeTimes->{{3.5663254642796717`*^9, 3.566325467582808*^9}, {
  3.5663274625214787`*^9, 3.566327472959866*^9}, {3.5663275320806913`*^9, 
  3.5663275321909513`*^9}, {3.5663281146560926`*^9, 
  3.566328116086904*^9}},ExpressionUUID->"e61bdca1-fec2-4c38-b409-\
93a1d76303df"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"aa", "=", "3"}], ";", 
  RowBox[{"bb", "=", "2"}], ";", 
  RowBox[{"cc", "=", "3"}], ";", 
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "2"}], "}"}]}], ";", 
  RowBox[{"Cvec", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{
      RowBox[{"-", "29"}], "/", "10"}], ",", 
     RowBox[{"19", "/", "10"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"soH", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "2"}], "}"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"5", " ", "kk"}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"7", " ", "kk"}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "2", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "32"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"4", " ", "kk"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"8", " ", "kk"}]]}], ")"}], " ", "y"}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"8", " ", "kk"}]]}], ")"}], " ", "kk", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"8", " ", "kk"}]]}], ")"}], " ", "y"}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"8", " ", "kk"}]]}], ")"}], " ", "kk", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["y", "2"]}], ")"}]}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "8"], " ", "kk", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "8"], " ", "kk", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y_"}], "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"y", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["y", "3"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["kk", "2"], " ", "y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"]}]]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "2"}], "}"}], "]"}], "=", 
   RowBox[{
    RowBox[{"OmS", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "2"}], "}"}], "]"}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"y", "-", 
        RowBox[{"1", "/", "y"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"-", "4"}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"y", "+", 
        RowBox[{"1", "/", "y"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"-", "2"}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"kk", "^", "2"}]}], " ", 
        RowBox[{"y", "^", "4"}]}], "-", 
       RowBox[{
        RowBox[{"kk", "^", "2"}], "/", 
        RowBox[{"y", "^", "4"}]}], "+", 
       RowBox[{"2", 
        RowBox[{"kk", "^", "2"}]}], "-", 
       RowBox[{"2", "kk"}], "+", 
       RowBox[{"y", "^", 
        RowBox[{"(", 
         RowBox[{"2", "-", 
          RowBox[{"4", "kk"}]}], ")"}]}], "+", 
       RowBox[{"y", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", "kk"}], "-", "2"}], ")"}]}], "+", 
       RowBox[{"kk", " ", 
        RowBox[{"y", "^", "4"}]}], "+", 
       RowBox[{"kk", "/", 
        RowBox[{"y", "^", "4"}]}], "-", 
       RowBox[{"y", "^", "2"}], "-", 
       RowBox[{"1", "/", 
        RowBox[{"y", "^", "2"}]}]}], ")"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.566327770188664*^9, 3.566327812378256*^9}, {
   3.566328118652231*^9, 3.566328128240313*^9}, {3.567153542831993*^9, 
   3.567153559405079*^9}, {3.567156120099228*^9, 3.567156128637188*^9}, 
   3.567156438312714*^9, 3.567163361976563*^9, {3.568654527197484*^9, 
   3.568654527645874*^9}, 3.568655271392836*^9, 3.570208243114966*^9, {
   3.58532652730083*^9, 3.585326527370853*^9}, 
   3.5854508343747*^9},ExpressionUUID->"c482c9a6-4c75-4bc0-b706-e7c2af8d878a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rank (2,2,2) ", "Section",
 CellChangeTimes->{{3.567163836203124*^9, 3.567163841433248*^9}, 
   3.568654555037694*^9},ExpressionUUID->"387da41a-313e-4d1e-bf32-\
104d8dcf669f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"aa", "=", "3"}], ";", 
  RowBox[{"bb", "=", "2"}], ";", 
  RowBox[{"cc", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nvec", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cvec", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "29"}], "/", "10"}], ",", 
     RowBox[{"19", "/", "10"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OmR", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2", ",", "2"}], "}"}], "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"3", " ", "kk", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "4"]}], ")"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", "-", 
        RowBox[{"8", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "y"]}], "+", "y"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", 
         RowBox[{
          RowBox[{"-", "16"}], " ", "kk"}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"16", " ", "kk"}]]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox["y", "2"]]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"4", "-", 
        RowBox[{"8", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", 
         RowBox[{
          RowBox[{"-", "16"}], " ", "kk"}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"16", " ", "kk"}]]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox["y", "2"]]}], "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"4", "-", 
        RowBox[{"8", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        SuperscriptBox["y", 
         RowBox[{
          RowBox[{"-", "16"}], " ", "kk"}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"16", " ", "kk"}]]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox["y", "2"]]}], "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"3", "-", 
        RowBox[{"8", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "16"}], " ", "kk"}]]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "kk"}]]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", " ", "kk"}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"16", " ", "kk"}]]}], ")"}]}], 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "y"]}], "+", "y"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox["y", "2"]]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"4", "-", 
        RowBox[{"8", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "4"}], "+", 
        SuperscriptBox["y", 
         RowBox[{
          RowBox[{"-", "16"}], " ", "kk"}]], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "kk"}]]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", " ", "kk"}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"16", " ", "kk"}]]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox["y", "2"]]}], "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"5", "-", 
        RowBox[{"8", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "16"}], " ", "kk"}]]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "8"}], " ", "kk"}]]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "4"}], " ", "kk"}]]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["y", 
          RowBox[{"4", " ", "kk"}]]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["y", 
          RowBox[{"8", " ", "kk"}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"16", " ", "kk"}]]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], "5"]}]], "+", 
    FractionBox[
     RowBox[{"kk", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"7", "-", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "kk"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "67"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}], " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"7", "-", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}], " ", 
         SuperscriptBox["y", "4"]}], "+", 
        RowBox[{"50", " ", 
         SuperscriptBox["kk", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}]}], 
     RowBox[{"48", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "4"]}]], "-", 
    FractionBox[
     RowBox[{"y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "kk"], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
         SuperscriptBox["y", "4"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
         SuperscriptBox["y", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["kk", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "4"]}], ")"}], "2"]}]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
    RowBox[{
     FractionBox["1", "256"], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}]], "+", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"7", " ", "kk"}]]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"9", " ", "kk"}]]}], "-", 
          RowBox[{"28", " ", 
           SuperscriptBox["kk", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"9", "-", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"7", " ", "kk"}]]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"9", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"7", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"9", " ", "kk"}]]}]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "y"}], ")"}], "4"]], "2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"29", " ", "kk"}]]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"31", " ", "kk"}]]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"49", " ", "kk"}]]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"51", " ", "kk"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"29", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"31", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"49", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"51", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"29", " ", "kk"}]]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"31", " ", "kk"}]]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"49", " ", "kk"}]]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"51", " ", "kk"}]]}]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}], "-", 
          RowBox[{"28", " ", 
           SuperscriptBox["kk", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "2"]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     FractionBox["1", "256"], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}]], "+", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"27", " ", "kk"}]]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"29", " ", "kk"}]]}], "-", 
          RowBox[{"28", " ", 
           SuperscriptBox["kk", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"27", " ", "kk"}]]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"29", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"27", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"29", " ", "kk"}]]}]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "y"}], ")"}], "4"]], "2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"49", " ", "kk"}]]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"51", " ", "kk"}]]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"69", " ", "kk"}]]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", 
            RowBox[{"71", " ", "kk"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"49", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"51", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"69", " ", "kk"}]]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"71", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"49", " ", "kk"}]]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"51", " ", "kk"}]]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"69", " ", "kk"}]]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"71", " ", "kk"}]]}]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}], "-", 
          RowBox[{"28", " ", 
           SuperscriptBox["kk", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "2"]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     FractionBox["1", "256"], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["6", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
       FractionBox["6", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "y"}], ")"}], "2"]], "-", 
       FractionBox[
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["y", "2"]}], "+", 
           SuperscriptBox["y", "4"]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}], ")"}], "3"]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "32"}], " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"32", " ", "kk"}]]}], ")"}], " ", "kk", " ", "y", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}], ")"}]}], "-", 
         RowBox[{"128", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"32", " ", "kk"}]]}], ")"}], " ", 
          SuperscriptBox["kk", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "7"}], "+", 
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"32", " ", "kk"}]]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["y", "2"]}], "+", 
            SuperscriptBox["y", "4"]}], ")"}]}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}], ")"}], "3"]]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"kk", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["y", "2"]}], ")"}], " ", 
      RowBox[{"OmS", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "6"}], " ", "kk"}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{
          RowBox[{"-", "4"}], " ", "kk"}]], "-", 
        SuperscriptBox["y", 
         RowBox[{"4", " ", "kk"}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"6", " ", "kk"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["y", "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]]}], "+", 
        RowBox[{"OmS", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}], "]"}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "y"]}], "+", "y"}], ")"}], "3"]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "y"]}], "+", "y"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"OmS", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], "]"}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox["y", "2"]]}], "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SuperscriptBox["y", "2"]]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "y"]}], "+", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"2", "-", 
           RowBox[{"2", " ", "kk"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox["y", "2"], ")"}], 
            RowBox[{
             RowBox[{"-", "4"}], " ", "kk"}]], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox["y", "2"], ")"}], 
            RowBox[{"4", " ", "kk"}]]}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", 
             SuperscriptBox["y", "2"]]}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
       RowBox[{"OmS", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], "]"}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
       FractionBox["2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}], " ", 
     RowBox[{"OmS", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "2"}], "}"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], "2"]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"2", "-", 
       RowBox[{"5", " ", "kk"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["y", 
        RowBox[{
         RowBox[{"-", "5"}], " ", "kk"}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"5", " ", "kk"}]]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"kk", " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", "y"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
            SuperscriptBox["y", "2"]}]}], ")"}]}], 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"]}]], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
          FractionBox["2", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}]]}], ")"}]}], "+", 
       RowBox[{"OmS", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2"}], "}"}], "]"}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "kk"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}], " ", 
     RowBox[{"OmS", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "1"}], "}"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], "2"]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"2", "+", 
       RowBox[{"5", " ", "kk"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["y", 
        RowBox[{
         RowBox[{"-", "5"}], " ", "kk"}]], "+", 
       SuperscriptBox["y", 
        RowBox[{"5", " ", "kk"}]]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"kk", " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", "y"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
            SuperscriptBox["y", "2"]}]}], ")"}]}], 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "2"]}]], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
          FractionBox["2", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}]]}], ")"}]}], "+", 
       RowBox[{"OmS", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1"}], "}"}], "]"}]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["y", "2"], " ", 
      RowBox[{"OmS", "[", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "1"}], "}"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", "-", 
        RowBox[{"2", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", 
         RowBox[{
          RowBox[{"-", "6"}], " ", "kk"}]], "+", 
        SuperscriptBox["y", 
         RowBox[{"6", " ", "kk"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"kk", " ", "y", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["y", "2"]}], ")"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]}]], "+", 
        RowBox[{
         FractionBox["1", "16"], " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["2", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
           FractionBox["2", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
           FractionBox[
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}]]}], ")"}]}], "+", 
        RowBox[{"OmS", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1", ",", "1"}], "}"}], "]"}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "y"]}], "+", "y"}], ")"}], "2"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "kk"}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"2", " ", "kk"}]]}], ")"}], " ", 
      RowBox[{"OmS", "[", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "2"}], "}"}], "]"}]}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "y"]}], "+", "y"}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "kk"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "kk"}]]}], "+", 
        SuperscriptBox["y", 
         RowBox[{"2", " ", "kk"}]]}], ")"}], " ", 
      RowBox[{"OmS", "[", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "1"}], "}"}], "]"}]}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "y"]}], "+", "y"}]], "+", 
    RowBox[{"OmS", "[", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"soH", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2", ",", "2"}], "}"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["2", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "2"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "2"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "2", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "64"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"8", " ", "y"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["y", "2"]}], ")"}], "2"]]}], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"8", " ", "kk"}]]}], ")"}], " ", "y"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "256"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["6", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]], "+", 
         FractionBox["6", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "-", 
         FractionBox[
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"6", " ", 
              SuperscriptBox["y", "2"]}], "+", 
             SuperscriptBox["y", "4"]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "3"]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "32"}], " ", "\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"32", " ", "kk"}]]}], ")"}], " ", "kk", " ", "y", " ", 
            
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["y", "2"]}], ")"}]}], "-", 
           RowBox[{"128", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"32", " ", "kk"}]]}], ")"}], " ", 
            SuperscriptBox["kk", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["y", "2"]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "7"}], "+", 
              SuperscriptBox["\[ImaginaryI]", 
               RowBox[{"32", " ", "kk"}]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"6", " ", 
               SuperscriptBox["y", "2"]}], "+", 
              SuperscriptBox["y", "4"]}], ")"}]}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["y", "2"]}], ")"}], "3"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "2"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y"}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}]}], ")"}]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2", ",", "2"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "4"]}], ")"}]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}]}], ")"}]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1", ",", "2"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "4"]}], ")"}]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "4"]}], ")"}]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}]}]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y"}], 
       "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["y", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["y", "2"], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["kk", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"]}]]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"4", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
            SuperscriptBox["y", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
            SuperscriptBox["y", "8"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["kk", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["y", "4"]}], ")"}], "2"]}]}], ")"}]}], 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["y", "2"]}], ")"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}], ")"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "2", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "256"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"27", " ", "kk"}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"29", " ", "kk"}]]}], "-", 
            RowBox[{"28", " ", 
             SuperscriptBox["kk", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", 
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"27", " ", "kk"}]]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"29", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"27", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"29", " ", "kk"}]]}]}], ")"}], " ", 
             SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "4"]], "2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"49", " ", "kk"}]]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"51", " ", "kk"}]]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"69", " ", "kk"}]]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"71", " ", "kk"}]]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"49", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"51", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"69", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"71", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"49", " ", "kk"}]]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"51", " ", "kk"}]]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"69", " ", "kk"}]]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"71", " ", "kk"}]]}]}], ")"}], " ", 
             SuperscriptBox["y", "2"]}], "-", 
            RowBox[{"28", " ", 
             SuperscriptBox["kk", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "y"}], ")"}], "2"]}]}], ")"}]}]}], ")"}]}]}],
      ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "256"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "4"]], "2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"7", " ", "kk"}]]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"9", " ", "kk"}]]}], "-", 
            RowBox[{"28", " ", 
             SuperscriptBox["kk", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"9", "-", 
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"7", " ", "kk"}]]}], "+", 
               RowBox[{"8", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"9", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"7", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"9", " ", "kk"}]]}]}], ")"}], " ", 
             SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "y"}], ")"}], "4"]], "2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"29", " ", "kk"}]]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"31", " ", "kk"}]]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"49", " ", "kk"}]]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[ImaginaryI]", 
              RowBox[{"51", " ", "kk"}]]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "9"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"29", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"31", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"49", " ", "kk"}]]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"51", " ", "kk"}]]}]}], ")"}], " ", "y"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"-", "1"}], ")"}], "kk"]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"29", " ", "kk"}]]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"31", " ", "kk"}]]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"49", " ", "kk"}]]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["\[ImaginaryI]", 
                 RowBox[{"51", " ", "kk"}]]}]}], ")"}], " ", 
             SuperscriptBox["y", "2"]}], "-", 
            RowBox[{"28", " ", 
             SuperscriptBox["kk", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "y"}], ")"}], "2"]}]}], ")"}]}]}], ")"}]}]}],
      ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
        "y"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
         "}"}], ",", "y"}], "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["y", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"7", "-", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "67"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"7", "-", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "kk"]}]}], ")"}], " ", 
           SuperscriptBox["y", "4"]}], "+", 
          RowBox[{"50", " ", 
           SuperscriptBox["kk", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["y", "2"]}], ")"}], "2"]}]}], ")"}]}], 
       RowBox[{"48", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "4"]}]]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.5663283817196712`*^9, {3.5663284160080757`*^9, 3.5663285400982113`*^9}, {
   3.56716377917233*^9, 3.567163806454636*^9}, {3.567163885402595*^9, 
   3.5671639083866463`*^9}, {3.567164061399148*^9, 3.567164096302244*^9}, {
   3.567164140059153*^9, 3.567164160763584*^9}, {3.567164192199637*^9, 
   3.567164197990588*^9}, {3.567164392873468*^9, 3.567164408306901*^9}, {
   3.5671644865769978`*^9, 3.567164494338677*^9}, {3.5671679160829697`*^9, 
   3.5671679292923822`*^9}, 3.5671680936000023`*^9, 3.567190542978012*^9, {
   3.568653588673753*^9, 3.568653589944827*^9}, {3.568655371811862*^9, 
   3.568655419517035*^9}, {3.568655487807643*^9, 3.568655492871702*^9}, 
   3.570208247970291*^9, {3.5853265365712*^9, 3.5853265693951597`*^9}, {
   3.585450835783173*^9, 
   3.585450846219866*^9}},ExpressionUUID->"d6789e70-f82d-4fa2-bc89-\
ed48050d6318"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evaluate the Poincare polynomial", "Section",
 CellChangeTimes->{{3.5663257400631237`*^9, 
  3.566325761342157*^9}},ExpressionUUID->"25f734d3-6ab5-488b-8944-\
5a3f3aebd6ce"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Mat", "=", 
     RowBox[{"(", GridBox[{
        {"0", "aa", 
         RowBox[{"-", "cc"}]},
        {
         RowBox[{"-", "aa"}], "0", "bb"},
        {"cc", 
         RowBox[{"-", "bb"}], "0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$QuiverMultiplier", "=", "kk"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$QuiverMultiplierAssumption", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kk", "\[Element]", "Integers"}], ",", 
       RowBox[{"kk", ">", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$QuiverNoLoop", "=", "False"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$QuiverTestLoop", "=", "True"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$QuiverDisplayCoulombH", "=", "True"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.566328225141891*^9, 3.566328248223687*^9}, {
   3.568654338472074*^9, 3.568654345956543*^9}, 3.568654857327799*^9, 
   3.568654927072019*^9, {3.568719104336364*^9, 3.568719106849306*^9}, {
   3.5687248899521503`*^9, 3.568724895438532*^9}, {3.5702081140306053`*^9, 
   3.5702081405643187`*^9}, {3.818224661918277*^9, 
   3.818224679571075*^9}},ExpressionUUID->"a700321c-7478-468e-9b6b-\
fd0229459f6b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"QPoinca", ",", "CoulombHRule"}], "}"}], "=", 
  RowBox[{"CoulombBranchFormula", "[", 
   RowBox[{"Mat", ",", "Cvec", ",", "Nvec"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.567148410310369*^9, 3.567148420296197*^9}, {
   3.567148550515356*^9, 3.5671485506224422`*^9}, 3.567148939293335*^9, {
   3.567148976483082*^9, 3.567148977386888*^9}, 3.567149477975313*^9, 
   3.56714955922652*^9, 3.5671639842904873`*^9, {3.567692496105288*^9, 
   3.567692496192925*^9}, {3.5685735248996058`*^9, 3.568573528467163*^9}, 
   3.568654581575203*^9, 3.568654670684155*^9, {3.568654801465993*^9, 
   3.568654806200012*^9}, {3.585326584966756*^9, 
   3.585326585182836*^9}},ExpressionUUID->"9ee5bf33-0a25-4aa3-8833-\
40152adf071f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"kk", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "kk"], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", "y"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
         SuperscriptBox["y", "2"]}]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"3", "-", "kk"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["y", 
          RowBox[{"-", "kk"}]]}], "+", 
        SuperscriptBox["y", "kk"]}], ")"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "y"]}], "+", "y"}], ")"}], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", "-", "kk"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["y", 
         RowBox[{"-", "kk"}]], "+", 
        SuperscriptBox["y", "kk"]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "y"]}], "+", "y"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox["y", "2"]]}], "+", 
        SuperscriptBox["y", "2"]}], ")"}]}]], "+", 
    RowBox[{
     FractionBox["1", "16"], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
       FractionBox["2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}]]}], ")"}]}], "+", 
    RowBox[{"OmS", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "y", ",", "t"}], 
     "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{
         RowBox[{"-", "4"}], " ", "kk"}]], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"2", " ", "kk"}]]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "+", 
         FractionBox[
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], 
            RowBox[{"4", " ", "kk"}]]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
      "\[Rule]", 
      RowBox[{
       FractionBox["1", "16"], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "kk"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
         FractionBox["2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"CoulombH", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], 
       "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"kk", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
           SuperscriptBox["y", "2"]}]}], ")"}]}], 
       RowBox[{"8", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5686546710953503`*^9, 3.568654710936853*^9, {3.568654757268724*^9, 
   3.56865480693929*^9}, 3.5686549319003963`*^9, 3.568655030775874*^9, 
   3.568655140608838*^9, 3.5686552385303507`*^9, 3.568655365676296*^9, 
   3.568719019513433*^9, 3.568719107806036*^9, 3.5687243793683*^9, {
   3.568724504931139*^9, 3.568724531002632*^9}, 3.56872457806885*^9, {
   3.568724666097653*^9, 3.568724713808898*^9}, {3.568724812907177*^9, 
   3.5687248367079144`*^9}, 3.568724869506373*^9, 3.5687248997526283`*^9, 
   3.568725967628731*^9, 3.570208089922016*^9, 3.570208141769211*^9, 
   3.5702081752707*^9, 3.570251147168517*^9, {3.570251276603825*^9, 
   3.570251322373487*^9}, 3.5702514669546337`*^9, 3.570251619823909*^9, 
   3.585326585539003*^9, 3.585326646386178*^9, {3.5853267192535887`*^9, 
   3.585326745872294*^9}, 3.5854508651946907`*^9, 3.5895186933144913`*^9, 
   3.589518746654357*^9, 3.818224650681013*^9, 
   3.818224682798189*^9},ExpressionUUID->"c7893ebe-4cae-4f95-8c71-\
a42ffe8a6930"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoulombHRuleAny", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"CoulombHRule", ",", 
    RowBox[{"kk", "\[Element]", "Integers"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.567149686774007*^9, 3.567149719796566*^9}, {
   3.567149923122407*^9, 3.5671499335369053`*^9}, {3.5671564045662394`*^9, 
   3.5671564067714767`*^9}, 3.56716358442279*^9, {3.567164042718727*^9, 
   3.567164046919486*^9}, 3.567164129654554*^9, {3.5671643699354773`*^9, 
   3.567164370694747*^9}, {3.568654817394359*^9, 3.568654817940278*^9}, 
   3.5686549636896257`*^9, 3.568655246909482*^9, {3.570251392286584*^9, 
   3.570251402315803*^9}, 
   3.5702516322097273`*^9},ExpressionUUID->"8702018b-2d10-4374-9a98-\
b489824d593f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"CoulombH", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
    "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["y", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "2"]]}]}], ",", 
   RowBox[{
    RowBox[{"CoulombH", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}], 
    "\[Rule]", 
    RowBox[{
     FractionBox["1", "16"], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "kk"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], "2"]]}], "-", 
       FractionBox["2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "y"}], ")"}], "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[ImaginaryI]", "kk"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"CoulombH", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", "y_"}], "]"}],
     "\[Rule]", 
    FractionBox[
     RowBox[{"kk", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "kk"], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", "y"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "kk"]}], ")"}], " ", 
         SuperscriptBox["y", "2"]}]}], ")"}]}], 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.57025139619652*^9, 3.570251403769123*^9}, 
   3.570251632955123*^9, 3.5853265902336073`*^9, 3.585326648566712*^9, 
   3.585326720529189*^9, 3.585326750848188*^9, 3.585450871019208*^9, 
   3.589518697186714*^9, 3.589518747590961*^9, 
   3.818224689929365*^9},ExpressionUUID->"aa93c672-7483-42d0-ac10-\
c55f81984560"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"DropFugacity", "[", "QPoinca", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"kk", ",", "1", ",", "8"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "50"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5671499556010303`*^9, 3.567149994188548*^9}, {
   3.5671500477579603`*^9, 3.567150048116626*^9}, {3.567150101767104*^9, 
   3.5671501076938553`*^9}, {3.567163328346925*^9, 3.5671633286029243`*^9}, {
   3.567164304401026*^9, 3.567164334856769*^9}, 3.5671918843759527`*^9, {
   3.567192037387673*^9, 3.567192037467291*^9}, {3.5671922032062798`*^9, 
   3.5671922227576027`*^9}, {3.568573768206373*^9, 3.568573774660915*^9}, {
   3.568574002055869*^9, 3.568574003805999*^9}, {3.568651747315214*^9, 
   3.5686517519608107`*^9}, {3.5686524168010397`*^9, 3.5686524170887947`*^9}, 
   3.568655164934266*^9, {3.568655442143025*^9, 3.56865544222549*^9}, {
   3.568655523254901*^9, 3.568655523307557*^9}, {3.570208192691997*^9, 
   3.57020819477155*^9}, {3.585450876390366*^9, 
   3.5854508797904367`*^9}},ExpressionUUID->"b903d57f-366a-49f0-97f0-\
c4cb778d2a8c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"OmS", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, 0, 51, 1],
      Editable->False]}],
    SeriesData[CoulombHiggs`y, 0, {
      CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t]}, 0, 51, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"OmS", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, 0, 51, 1],
      Editable->False]}],
    SeriesData[CoulombHiggs`y, 0, {
      CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t]}, 0, 51, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"OmS", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, 0, 51, 1],
      Editable->False]}],
    SeriesData[CoulombHiggs`y, 0, {
      CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t]}, 0, 51, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"OmS", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, 0, 51, 1],
      Editable->False]}],
    SeriesData[CoulombHiggs`y, 0, {
      CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t]}, 0, 51, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"OmS", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}]}], 
      ")"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, 0, 51, 1],
      Editable->False]}],
    SeriesData[
    CoulombHiggs`y, 0, {1 + CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t]}, 0, 
     51, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "y"]}], "+", 
     RowBox[{"OmS", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}], "-", "y",
      "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, -1, 51, 1],
      Editable->False]}],
    SeriesData[CoulombHiggs`y, 0, {-1, 
      CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t], -1}, -1, 51, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["y", "2"]], "+", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"OmS", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}]}], 
      ")"}], "+", 
     SuperscriptBox["y", "2"], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, -2, 51, 1],
      Editable->False]}],
    SeriesData[
    CoulombHiggs`y, 0, {
     1, 0, 2 + CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t], 0, 1}, -2, 51, 1],
    
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       SuperscriptBox["y", "3"]]}], "-", 
     FractionBox["2", "y"], "+", 
     RowBox[{"OmS", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "2"}], "}"}], ",", "t"}], "]"}], "-", 
     RowBox[{"2", " ", "y"}], "-", 
     SuperscriptBox["y", "3"], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "y", "]"}], "51"],
      SeriesData[CoulombHiggs`y, 0, {}, -3, 51, 1],
      Editable->False]}],
    SeriesData[CoulombHiggs`y, 0, {-1, 0, -2, 
      CoulombHiggs`OmS[{1, 1, 2}, CoulombHiggs`t], -2, 0, -1}, -3, 51, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.568654723153307*^9, 3.56865478769123*^9, 3.568654938243637*^9, 
   3.568655042255047*^9, 3.568655184050074*^9, 3.56865525025478*^9, {
   3.5686554369780397`*^9, 3.568655443532164*^9}, 3.5686555236690893`*^9, {
   3.5687248748920813`*^9, 3.5687249011956043`*^9}, 3.570208150960698*^9, {
   3.5702081816707563`*^9, 3.570208195086605*^9}, 3.570251642673752*^9, 
   3.585326593964415*^9, 3.5853266499730263`*^9, {3.585326722146687*^9, 
   3.585326752050148*^9}, 3.5854508829683437`*^9, 3.589518699721615*^9, 
   3.589518748641946*^9, 
   3.818224697578828*^9},ExpressionUUID->"1cec723e-ef94-4a54-aa97-\
3051eba0e887"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"DropFugacity", "[", "QPoinca", "]"}], "/.", 
         RowBox[{
          RowBox[{"OmS", "[", 
           RowBox[{"gam_", ",", "t_"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"OmS", "[", "gam", "]"}]}]}], ")"}], "-", 
       RowBox[{"OmR", "[", "Nvec", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "30"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"kk", ",", "1", ",", "8"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.567148533047392*^9, {3.567149448757525*^9, 3.567149449093049*^9}, {
   3.567149945297329*^9, 3.5671499488460703`*^9}, {3.567156243120302*^9, 
   3.5671562432397537`*^9}, {3.5671904954858217`*^9, 3.567190495972773*^9}, {
   3.56719063531912*^9, 3.567190642215526*^9}, {3.567191890167862*^9, 
   3.567191890324526*^9}, {3.567701365214698*^9, 3.5677013656210337`*^9}, {
   3.568651754713307*^9, 3.568651755028638*^9}, {3.568653425557316*^9, 
   3.568653454613285*^9}, {3.5686540431833353`*^9, 3.568654043525689*^9}, {
   3.568654109215294*^9, 3.5686541451247*^9}, 3.568654731858499*^9, {
   3.568655192247843*^9, 3.568655193550044*^9}, 3.5702081541360407`*^9, {
   3.5702081994823713`*^9, 3.5702082081878023`*^9}, {3.585450887772771*^9, 
   3.585450890750393*^9}, {3.589518709575533*^9, 
   3.589518724734315*^9}},ExpressionUUID->"c1984255-8e91-447a-b1f4-\
e8f55e63201b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "y", "]"}], "31"],
    SeriesData[CoulombHiggs`y, 0, {}, 31, 31, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.567701234375537*^9, 3.567701244510601*^9}, {
   3.567701361616227*^9, 3.56770136614186*^9}, 3.5677016379987907`*^9, 
   3.5685736169321537`*^9, {3.568573647115432*^9, 3.56857367523252*^9}, 
   3.568573707574833*^9, 3.568573762907729*^9, 3.568574008146071*^9, {
   3.568651738941785*^9, 3.568651755396154*^9}, 3.568651886656663*^9, 
   3.5686533182320833`*^9, {3.568653426501811*^9, 3.568653455541366*^9}, 
   3.568653530000188*^9, {3.568654035996994*^9, 3.568654043948587*^9}, {
   3.568654097428286*^9, 3.568654145618833*^9}, {3.568654728282696*^9, 
   3.568654732309696*^9}, 3.568654788907318*^9, 3.568654939493565*^9, 
   3.568655044928973*^9, {3.568655186382039*^9, 3.568655193937366*^9}, 
   3.5686552516703053`*^9, {3.568724875742038*^9, 3.568724902163249*^9}, 
   3.57020815428332*^9, {3.570208184494854*^9, 3.570208208515641*^9}, 
   3.5702516435048037`*^9, 3.5853265987382708`*^9, {3.585326631201284*^9, 
   3.585326651559792*^9}, {3.585326725331895*^9, 3.585326755285344*^9}, 
   3.585450891153448*^9, {3.5895187028970327`*^9, 3.589518749672832*^9}, 
   3.818224699894347*^9},ExpressionUUID->"f0d28b55-faa8-45a0-8c98-\
94e4ac06c4f4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 607},
WindowMargins->{{Automatic, 187}, {Automatic, 14}},
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 16, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 270, 4, 77, "Title", "ExpressionUUID" -> \
"44013ac8-bf55-4b15-a225-bf122abbf38a"],
Cell[852, 28, 323, 7, 26, "Text", "ExpressionUUID" -> \
"1eb4ff90-0422-4969-a01b-4eebd3955371"],
Cell[CellGroupData[{
Cell[1200, 39, 506, 11, 51, "Input", "ExpressionUUID" -> \
"9b1a5b66-c34c-4b8f-be54-9fbe88c7dd9e"],
Cell[1709, 52, 428, 7, 24, "Print", "ExpressionUUID" -> \
"37df4785-99cc-4c20-b2c3-8c2fa462132c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2174, 64, 249, 4, 68, "Section", "ExpressionUUID" -> \
"24fe8327-c52f-44db-8d97-de753841205c"],
Cell[2426, 70, 504, 10, 41, "Text", "ExpressionUUID" -> \
"01b5f7c7-3d16-41da-b85f-f8047abfbca7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2967, 85, 244, 4, 62, "Section", "ExpressionUUID" -> \
"3404a405-dc6b-4182-9895-e520c326bd11"],
Cell[CellGroupData[{
Cell[3236, 93, 5056, 144, 232, "Input", "ExpressionUUID" -> \
"faa29396-6266-40a7-a96b-82d1dbbc5752"],
Cell[8295, 239, 1444, 24, 31, "Output", "ExpressionUUID" -> \
"66e0e157-8b3f-4ff3-bfa3-47f7883dc753"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9788, 269, 244, 4, 62, "Section", "ExpressionUUID" -> \
"286d456b-a783-48c1-b73f-625c95b35ab5"],
Cell[CellGroupData[{
Cell[10057, 277, 8749, 266, 386, "Input", "ExpressionUUID" -> \
"26906044-0bf2-456d-bd7e-27bdf0eaa1f4"],
Cell[18809, 545, 823, 15, 31, "Output", "ExpressionUUID" -> \
"6d6066db-c544-4da9-aed2-af6781ccc471"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19681, 566, 294, 4, 62, "Section", "ExpressionUUID" -> \
"ef3ff091-982a-4f9c-8681-96b855eea079"],
Cell[CellGroupData[{
Cell[20000, 574, 22269, 658, 1017, "Input", "ExpressionUUID" -> \
"9084add1-a875-43d7-92d3-b198f4e07d48"],
Cell[42272, 1234, 322, 8, 31, "Output", "ExpressionUUID" -> \
"70393c3a-8c27-4dfc-a77a-9284c2c4fcbb"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42643, 1248, 394, 6, 62, "Section", "ExpressionUUID" -> \
"799f5485-9c3c-490d-b26a-b3dad097375e"],
Cell[CellGroupData[{
Cell[43062, 1258, 59534, 1751, 2467, "Input", "ExpressionUUID" -> \
"8691f96e-cfa9-4e62-9b8e-660f27193b81"],
Cell[102599, 3011, 275, 7, 31, "Output", "ExpressionUUID" -> \
"ae86ce07-3344-455f-a3e1-1d02274bfb8f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[102923, 3024, 345, 5, 62, "Section", "ExpressionUUID" -> \
"e61bdca1-fec2-4c38-b409-93a1d76303df"],
Cell[103271, 3031, 19949, 583, 938, "Input", "ExpressionUUID" -> \
"c482c9a6-4c75-4bc0-b706-e7c2af8d878a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123257, 3619, 181, 3, 68, "Section", "ExpressionUUID" -> \
"387da41a-313e-4d1e-bf32-104d8dcf669f"],
Cell[123441, 3624, 102289, 2980, 4957, "Input", "ExpressionUUID" -> \
"d6789e70-f82d-4fa2-bc89-ed48050d6318"]
}, Open  ]],
Cell[CellGroupData[{
Cell[225767, 6609, 179, 3, 68, "Section", "ExpressionUUID" -> \
"25f734d3-6ab5-488b-8944-5a3f3aebd6ce"],
Cell[225949, 6614, 1760, 44, 184, "Input", "ExpressionUUID" -> \
"a700321c-7478-468e-9b6b-fd0229459f6b"],
Cell[CellGroupData[{
Cell[227734, 6662, 766, 14, 31, "Input", "ExpressionUUID" -> \
"9ee5bf33-0a25-4aa3-8833-40152adf071f"],
Cell[228503, 6678, 8353, 250, 341, "Output", "ExpressionUUID" -> \
"c7893ebe-4cae-4f95-8c71-a42ffe8a6930"]
}, Open  ]],
Cell[CellGroupData[{
Cell[236893, 6933, 723, 13, 31, "Input", "ExpressionUUID" -> \
"8702018b-2d10-4374-9a98-b489824d593f"],
Cell[237619, 6948, 3779, 116, 195, "Output", "ExpressionUUID" -> \
"aa93c672-7483-42d0-ac10-c55f81984560"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241435, 7069, 1230, 23, 31, "Input", "ExpressionUUID" -> \
"b903d57f-366a-49f0-97f0-c4cb778d2a8c"],
Cell[242668, 7094, 4987, 146, 137, "Output", "ExpressionUUID" -> \
"1cec723e-ef94-4a54-aa97-3051eba0e887"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247692, 7245, 1531, 32, 70, "Input", "ExpressionUUID" -> \
"c1984255-8e91-447a-b1f4-e8f55e63201b"],
Cell[249226, 7279, 2515, 59, 34, "Output", "ExpressionUUID" -> \
"f0d28b55-faa8-45a0-8c98-94e4ac06c4f4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

